# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'D4mat2SlicerQ_Main.ui'
#
# Created: Mon Aug 30 22:13:35 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(585, 766)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.Panel1 = QtGui.QGroupBox(self.centralwidget)
        self.Panel1.setGeometry(QtCore.QRect(10, 220, 560, 161))
        self.Panel1.setObjectName("Panel1")
        self.txt14_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt14_p1.setGeometry(QtCore.QRect(310, 130, 60, 20))
        self.txt14_p1.setText("")
        self.txt14_p1.setObjectName("txt14_p1")
        self.txt13_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt13_p1.setGeometry(QtCore.QRect(150, 130, 60, 20))
        self.txt13_p1.setObjectName("txt13_p1")
        self.label15 = QtGui.QLabel(self.Panel1)
        self.label15.setGeometry(QtCore.QRect(0, 130, 68, 17))
        self.label15.setObjectName("label15")
        self.txt2_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt2_p1.setGeometry(QtCore.QRect(260, 30, 60, 20))
        self.txt2_p1.setObjectName("txt2_p1")
        self.label7 = QtGui.QLabel(self.Panel1)
        self.label7.setGeometry(QtCore.QRect(190, 50, 65, 20))
        self.label7.setObjectName("label7")
        self.txt11_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt11_p1.setGeometry(QtCore.QRect(260, 100, 60, 20))
        self.txt11_p1.setObjectName("txt11_p1")
        self.txt15_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt15_p1.setGeometry(QtCore.QRect(460, 130, 60, 20))
        self.txt15_p1.setObjectName("txt15_p1")
        self.txt5_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt5_p1.setGeometry(QtCore.QRect(260, 50, 60, 20))
        self.txt5_p1.setObjectName("txt5_p1")
        self.txt6_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt6_p1.setGeometry(QtCore.QRect(410, 50, 60, 20))
        self.txt6_p1.setObjectName("txt6_p1")
        self.label4 = QtGui.QLabel(self.Panel1)
        self.label4.setGeometry(QtCore.QRect(190, 30, 65, 20))
        self.label4.setObjectName("label4")
        self.label6 = QtGui.QLabel(self.Panel1)
        self.label6.setGeometry(QtCore.QRect(30, 50, 65, 20))
        self.label6.setObjectName("label6")
        self.label14 = QtGui.QLabel(self.Panel1)
        self.label14.setGeometry(QtCore.QRect(340, 100, 65, 20))
        self.label14.setObjectName("label14")
        self.label18 = QtGui.QLabel(self.Panel1)
        self.label18.setGeometry(QtCore.QRect(380, 130, 31, 17))
        self.label18.setObjectName("label18")
        self.txt4_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt4_p1.setGeometry(QtCore.QRect(100, 50, 60, 20))
        self.txt4_p1.setObjectName("txt4_p1")
        self.txt8_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt8_p1.setGeometry(QtCore.QRect(260, 80, 60, 20))
        self.txt8_p1.setObjectName("txt8_p1")
        self.label8 = QtGui.QLabel(self.Panel1)
        self.label8.setGeometry(QtCore.QRect(340, 50, 65, 20))
        self.label8.setObjectName("label8")
        self.chRotateAxis3rd = QtGui.QComboBox(self.Panel1)
        self.chRotateAxis3rd.setGeometry(QtCore.QRect(410, 130, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.chRotateAxis3rd.setFont(font)
        self.chRotateAxis3rd.setEditable(False)
        self.chRotateAxis3rd.setObjectName("chRotateAxis3rd")
        self.chRotateAxis3rd.addItem("")
        self.chRotateAxis3rd.setItemText(0, "")
        self.chRotateAxis3rd.addItem("")
        self.chRotateAxis3rd.addItem("")
        self.chRotateAxis3rd.addItem("")
        self.label17 = QtGui.QLabel(self.Panel1)
        self.label17.setGeometry(QtCore.QRect(230, 130, 31, 17))
        self.label17.setObjectName("label17")
        self.txt1_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt1_p1.setGeometry(QtCore.QRect(100, 30, 60, 20))
        self.txt1_p1.setObjectName("txt1_p1")
        self.txt9_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt9_p1.setGeometry(QtCore.QRect(410, 80, 60, 20))
        self.txt9_p1.setObjectName("txt9_p1")
        self.txt12_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt12_p1.setGeometry(QtCore.QRect(410, 100, 60, 20))
        self.txt12_p1.setObjectName("txt12_p1")
        self.label11 = QtGui.QLabel(self.Panel1)
        self.label11.setGeometry(QtCore.QRect(340, 80, 65, 20))
        self.label11.setObjectName("label11")
        self.label10 = QtGui.QLabel(self.Panel1)
        self.label10.setGeometry(QtCore.QRect(190, 80, 65, 20))
        self.label10.setObjectName("label10")
        self.chRotateAxis2nd = QtGui.QComboBox(self.Panel1)
        self.chRotateAxis2nd.setGeometry(QtCore.QRect(260, 130, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.chRotateAxis2nd.setFont(font)
        self.chRotateAxis2nd.setEditable(False)
        self.chRotateAxis2nd.setObjectName("chRotateAxis2nd")
        self.chRotateAxis2nd.addItem("")
        self.chRotateAxis2nd.setItemText(0, "")
        self.chRotateAxis2nd.addItem("")
        self.chRotateAxis2nd.addItem("")
        self.chRotateAxis2nd.addItem("")
        self.label13 = QtGui.QLabel(self.Panel1)
        self.label13.setGeometry(QtCore.QRect(190, 100, 65, 20))
        self.label13.setObjectName("label13")
        self.chRotateAxis1st = QtGui.QComboBox(self.Panel1)
        self.chRotateAxis1st.setGeometry(QtCore.QRect(100, 130, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.chRotateAxis1st.setFont(font)
        self.chRotateAxis1st.setEditable(False)
        self.chRotateAxis1st.setObjectName("chRotateAxis1st")
        self.chRotateAxis1st.addItem("")
        self.chRotateAxis1st.setItemText(0, "")
        self.chRotateAxis1st.addItem("")
        self.chRotateAxis1st.addItem("")
        self.chRotateAxis1st.addItem("")
        self.label3 = QtGui.QLabel(self.Panel1)
        self.label3.setGeometry(QtCore.QRect(30, 30, 65, 20))
        self.label3.setObjectName("label3")
        self.txt3_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt3_p1.setGeometry(QtCore.QRect(410, 30, 60, 20))
        self.txt3_p1.setObjectName("txt3_p1")
        self.label16 = QtGui.QLabel(self.Panel1)
        self.label16.setGeometry(QtCore.QRect(70, 130, 31, 17))
        self.label16.setObjectName("label16")
        self.txt7_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt7_p1.setGeometry(QtCore.QRect(100, 80, 60, 20))
        self.txt7_p1.setObjectName("txt7_p1")
        self.label5 = QtGui.QLabel(self.Panel1)
        self.label5.setGeometry(QtCore.QRect(340, 30, 65, 20))
        self.label5.setObjectName("label5")
        self.txt10_p1 = QtGui.QLineEdit(self.Panel1)
        self.txt10_p1.setGeometry(QtCore.QRect(100, 100, 60, 20))
        self.txt10_p1.setObjectName("txt10_p1")
        self.label9 = QtGui.QLabel(self.Panel1)
        self.label9.setGeometry(QtCore.QRect(30, 80, 65, 20))
        self.label9.setObjectName("label9")
        self.label12 = QtGui.QLabel(self.Panel1)
        self.label12.setGeometry(QtCore.QRect(30, 100, 65, 20))
        self.label12.setObjectName("label12")
        self.Panel2 = QtGui.QGroupBox(self.centralwidget)
        self.Panel2.setGeometry(QtCore.QRect(10, 380, 560, 131))
        self.Panel2.setObjectName("Panel2")
        self.txt1_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt1_p2.setGeometry(QtCore.QRect(40, 40, 55, 20))
        self.txt1_p2.setObjectName("txt1_p2")
        self.label25 = QtGui.QLabel(self.Panel2)
        self.label25.setGeometry(QtCore.QRect(10, 40, 31, 17))
        self.label25.setObjectName("label25")
        self.txt2_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt2_p2.setGeometry(QtCore.QRect(100, 40, 55, 20))
        self.txt2_p2.setObjectName("txt2_p2")
        self.txt3_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt3_p2.setGeometry(QtCore.QRect(160, 40, 55, 20))
        self.txt3_p2.setObjectName("txt3_p2")
        self.txt4_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt4_p2.setEnabled(False)
        self.txt4_p2.setGeometry(QtCore.QRect(220, 40, 55, 20))
        self.txt4_p2.setObjectName("txt4_p2")
        self.txt9_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt9_p2.setEnabled(False)
        self.txt9_p2.setGeometry(QtCore.QRect(220, 60, 55, 20))
        self.txt9_p2.setObjectName("txt9_p2")
        self.label26 = QtGui.QLabel(self.Panel2)
        self.label26.setGeometry(QtCore.QRect(10, 60, 31, 17))
        self.label26.setObjectName("label26")
        self.txt8_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt8_p2.setGeometry(QtCore.QRect(160, 60, 55, 20))
        self.txt8_p2.setObjectName("txt8_p2")
        self.txt6_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt6_p2.setGeometry(QtCore.QRect(40, 60, 55, 20))
        self.txt6_p2.setObjectName("txt6_p2")
        self.txt7_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt7_p2.setGeometry(QtCore.QRect(100, 60, 55, 20))
        self.txt7_p2.setObjectName("txt7_p2")
        self.label27 = QtGui.QLabel(self.Panel2)
        self.label27.setGeometry(QtCore.QRect(10, 80, 31, 17))
        self.label27.setObjectName("label27")
        self.label28 = QtGui.QLabel(self.Panel2)
        self.label28.setGeometry(QtCore.QRect(10, 100, 31, 17))
        self.label28.setObjectName("label28")
        self.txt5_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt5_p2.setGeometry(QtCore.QRect(290, 40, 91, 20))
        self.txt5_p2.setObjectName("txt5_p2")
        self.txt10_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt10_p2.setGeometry(QtCore.QRect(290, 60, 91, 20))
        self.txt10_p2.setObjectName("txt10_p2")
        self.label19 = QtGui.QLabel(self.Panel2)
        self.label19.setGeometry(QtCore.QRect(40, 20, 55, 20))
        self.label19.setAlignment(QtCore.Qt.AlignCenter)
        self.label19.setObjectName("label19")
        self.label20 = QtGui.QLabel(self.Panel2)
        self.label20.setGeometry(QtCore.QRect(100, 20, 55, 20))
        self.label20.setAlignment(QtCore.Qt.AlignCenter)
        self.label20.setObjectName("label20")
        self.label21 = QtGui.QLabel(self.Panel2)
        self.label21.setGeometry(QtCore.QRect(160, 20, 55, 20))
        self.label21.setAlignment(QtCore.Qt.AlignCenter)
        self.label21.setObjectName("label21")
        self.label23 = QtGui.QLabel(self.Panel2)
        self.label23.setGeometry(QtCore.QRect(220, 20, 55, 20))
        self.label23.setAlignment(QtCore.Qt.AlignCenter)
        self.label23.setObjectName("label23")
        self.label24 = QtGui.QLabel(self.Panel2)
        self.label24.setGeometry(QtCore.QRect(290, 20, 91, 20))
        self.label24.setAlignment(QtCore.Qt.AlignCenter)
        self.label24.setObjectName("label24")
        self.txt16_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt16_p2.setEnabled(False)
        self.txt16_p2.setGeometry(QtCore.QRect(40, 100, 55, 20))
        self.txt16_p2.setObjectName("txt16_p2")
        self.txt18_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt18_p2.setEnabled(False)
        self.txt18_p2.setGeometry(QtCore.QRect(160, 100, 55, 20))
        self.txt18_p2.setObjectName("txt18_p2")
        self.txt17_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt17_p2.setEnabled(False)
        self.txt17_p2.setGeometry(QtCore.QRect(100, 100, 55, 20))
        self.txt17_p2.setObjectName("txt17_p2")
        self.txt14_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt14_p2.setEnabled(False)
        self.txt14_p2.setGeometry(QtCore.QRect(220, 80, 55, 20))
        self.txt14_p2.setObjectName("txt14_p2")
        self.txt15_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt15_p2.setGeometry(QtCore.QRect(290, 80, 91, 20))
        self.txt15_p2.setObjectName("txt15_p2")
        self.txt13_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt13_p2.setGeometry(QtCore.QRect(160, 80, 55, 20))
        self.txt13_p2.setObjectName("txt13_p2")
        self.txt11_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt11_p2.setGeometry(QtCore.QRect(40, 80, 55, 20))
        self.txt11_p2.setObjectName("txt11_p2")
        self.txt19_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt19_p2.setGeometry(QtCore.QRect(220, 100, 55, 20))
        self.txt19_p2.setObjectName("txt19_p2")
        self.txt12_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt12_p2.setGeometry(QtCore.QRect(100, 80, 55, 20))
        self.txt12_p2.setObjectName("txt12_p2")
        self.txt20_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt20_p2.setGeometry(QtCore.QRect(290, 100, 91, 20))
        self.txt20_p2.setObjectName("txt20_p2")
        self.btProjectionAll = QtGui.QPushButton(self.Panel2)
        self.btProjectionAll.setGeometry(QtCore.QRect(458, 30, 91, 41))
        self.btProjectionAll.setObjectName("btProjectionAll")
        self.btProjectionClear = QtGui.QPushButton(self.Panel2)
        self.btProjectionClear.setGeometry(QtCore.QRect(480, 90, 60, 27))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btProjectionClear.setFont(font)
        self.btProjectionClear.setObjectName("btProjectionClear")
        self.txt21_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt21_p2.setGeometry(QtCore.QRect(390, 40, 61, 20))
        self.txt21_p2.setObjectName("txt21_p2")
        self.txt22_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt22_p2.setGeometry(QtCore.QRect(390, 60, 61, 20))
        self.txt22_p2.setObjectName("txt22_p2")
        self.txt23_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt23_p2.setGeometry(QtCore.QRect(390, 80, 61, 20))
        self.txt23_p2.setObjectName("txt23_p2")
        self.txt24_p2 = QtGui.QLineEdit(self.Panel2)
        self.txt24_p2.setGeometry(QtCore.QRect(390, 100, 61, 20))
        self.txt24_p2.setObjectName("txt24_p2")
        self.label24_2 = QtGui.QLabel(self.Panel2)
        self.label24_2.setGeometry(QtCore.QRect(390, 20, 61, 20))
        self.label24_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label24_2.setObjectName("label24_2")
        self.Panel3 = QtGui.QGroupBox(self.centralwidget)
        self.Panel3.setGeometry(QtCore.QRect(10, 510, 560, 151))
        self.Panel3.setFlat(False)
        self.Panel3.setObjectName("Panel3")
        self.label33 = QtGui.QLabel(self.Panel3)
        self.label33.setGeometry(QtCore.QRect(0, 60, 31, 17))
        self.label33.setObjectName("label33")
        self.txt1_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt1_p3.setGeometry(QtCore.QRect(30, 60, 60, 20))
        self.txt1_p3.setObjectName("txt1_p3")
        self.label34 = QtGui.QLabel(self.Panel3)
        self.label34.setGeometry(QtCore.QRect(100, 60, 16, 17))
        self.label34.setObjectName("label34")
        self.txt2_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt2_p3.setGeometry(QtCore.QRect(120, 60, 60, 20))
        self.txt2_p3.setObjectName("txt2_p3")
        self.btAutoFillAx1 = QtGui.QPushButton(self.Panel3)
        self.btAutoFillAx1.setGeometry(QtCore.QRect(190, 60, 32, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btAutoFillAx1.setFont(font)
        self.btAutoFillAx1.setObjectName("btAutoFillAx1")
        self.txtFold1 = QtGui.QLineEdit(self.Panel3)
        self.txtFold1.setGeometry(QtCore.QRect(240, 60, 40, 20))
        self.txtFold1.setObjectName("txtFold1")
        self.kbUseAx1Fold = QtGui.QCheckBox(self.Panel3)
        self.kbUseAx1Fold.setGeometry(QtCore.QRect(310, 60, 61, 22))
        self.kbUseAx1Fold.setObjectName("kbUseAx1Fold")
        self.v1ch = QtGui.QComboBox(self.Panel3)
        self.v1ch.setGeometry(QtCore.QRect(380, 60, 100, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.v1ch.setFont(font)
        self.v1ch.setObjectName("v1ch")
        self.v1ch.addItem("")
        self.v1ch.addItem("")
        self.v1ch.addItem("")
        self.v1ch.addItem("")
        self.txt3_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt3_p3.setGeometry(QtCore.QRect(490, 60, 60, 20))
        self.txt3_p3.setObjectName("txt3_p3")
        self.btAutoFillAx2 = QtGui.QPushButton(self.Panel3)
        self.btAutoFillAx2.setGeometry(QtCore.QRect(190, 80, 32, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btAutoFillAx2.setFont(font)
        self.btAutoFillAx2.setObjectName("btAutoFillAx2")
        self.kbUseAx2Fold = QtGui.QCheckBox(self.Panel3)
        self.kbUseAx2Fold.setGeometry(QtCore.QRect(310, 80, 61, 22))
        self.kbUseAx2Fold.setObjectName("kbUseAx2Fold")
        self.label36 = QtGui.QLabel(self.Panel3)
        self.label36.setGeometry(QtCore.QRect(100, 80, 16, 17))
        self.label36.setObjectName("label36")
        self.txt5_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt5_p3.setGeometry(QtCore.QRect(120, 80, 60, 20))
        self.txt5_p3.setObjectName("txt5_p3")
        self.txt6_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt6_p3.setGeometry(QtCore.QRect(490, 80, 60, 20))
        self.txt6_p3.setObjectName("txt6_p3")
        self.v2ch = QtGui.QComboBox(self.Panel3)
        self.v2ch.setGeometry(QtCore.QRect(380, 80, 100, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.v2ch.setFont(font)
        self.v2ch.setObjectName("v2ch")
        self.v2ch.addItem("")
        self.v2ch.addItem("")
        self.v2ch.addItem("")
        self.v2ch.addItem("")
        self.label35 = QtGui.QLabel(self.Panel3)
        self.label35.setGeometry(QtCore.QRect(0, 80, 31, 17))
        self.label35.setObjectName("label35")
        self.txt4_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt4_p3.setGeometry(QtCore.QRect(30, 80, 60, 20))
        self.txt4_p3.setObjectName("txt4_p3")
        self.txtFold2 = QtGui.QLineEdit(self.Panel3)
        self.txtFold2.setGeometry(QtCore.QRect(240, 80, 40, 20))
        self.txtFold2.setObjectName("txtFold2")
        self.btAutoFillAx3 = QtGui.QPushButton(self.Panel3)
        self.btAutoFillAx3.setGeometry(QtCore.QRect(190, 100, 32, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btAutoFillAx3.setFont(font)
        self.btAutoFillAx3.setObjectName("btAutoFillAx3")
        self.kbUseAx3Fold = QtGui.QCheckBox(self.Panel3)
        self.kbUseAx3Fold.setGeometry(QtCore.QRect(310, 100, 61, 22))
        self.kbUseAx3Fold.setObjectName("kbUseAx3Fold")
        self.label38 = QtGui.QLabel(self.Panel3)
        self.label38.setGeometry(QtCore.QRect(100, 100, 16, 17))
        self.label38.setObjectName("label38")
        self.txt8_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt8_p3.setGeometry(QtCore.QRect(120, 100, 60, 20))
        self.txt8_p3.setObjectName("txt8_p3")
        self.txt9_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt9_p3.setGeometry(QtCore.QRect(490, 100, 60, 20))
        self.txt9_p3.setObjectName("txt9_p3")
        self.v3ch = QtGui.QComboBox(self.Panel3)
        self.v3ch.setGeometry(QtCore.QRect(380, 100, 100, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.v3ch.setFont(font)
        self.v3ch.setObjectName("v3ch")
        self.v3ch.addItem("")
        self.v3ch.addItem("")
        self.v3ch.addItem("")
        self.v3ch.addItem("")
        self.label37 = QtGui.QLabel(self.Panel3)
        self.label37.setGeometry(QtCore.QRect(0, 100, 31, 17))
        self.label37.setObjectName("label37")
        self.txt7_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt7_p3.setGeometry(QtCore.QRect(30, 100, 60, 20))
        self.txt7_p3.setObjectName("txt7_p3")
        self.txtFold3 = QtGui.QLineEdit(self.Panel3)
        self.txtFold3.setGeometry(QtCore.QRect(240, 100, 40, 20))
        self.txtFold3.setObjectName("txtFold3")
        self.btAutoFillAx4 = QtGui.QPushButton(self.Panel3)
        self.btAutoFillAx4.setGeometry(QtCore.QRect(190, 120, 32, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btAutoFillAx4.setFont(font)
        self.btAutoFillAx4.setObjectName("btAutoFillAx4")
        self.kbUseAx4Fold = QtGui.QCheckBox(self.Panel3)
        self.kbUseAx4Fold.setGeometry(QtCore.QRect(310, 120, 61, 22))
        self.kbUseAx4Fold.setObjectName("kbUseAx4Fold")
        self.label40 = QtGui.QLabel(self.Panel3)
        self.label40.setGeometry(QtCore.QRect(100, 120, 16, 17))
        self.label40.setObjectName("label40")
        self.txt11_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt11_p3.setGeometry(QtCore.QRect(120, 120, 60, 20))
        self.txt11_p3.setObjectName("txt11_p3")
        self.txt12_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt12_p3.setGeometry(QtCore.QRect(490, 120, 60, 20))
        self.txt12_p3.setObjectName("txt12_p3")
        self.v4ch = QtGui.QComboBox(self.Panel3)
        self.v4ch.setGeometry(QtCore.QRect(380, 120, 100, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.v4ch.setFont(font)
        self.v4ch.setObjectName("v4ch")
        self.v4ch.addItem("")
        self.v4ch.addItem("")
        self.v4ch.addItem("")
        self.v4ch.addItem("")
        self.label39 = QtGui.QLabel(self.Panel3)
        self.label39.setGeometry(QtCore.QRect(0, 120, 31, 17))
        self.label39.setObjectName("label39")
        self.txt10_p3 = QtGui.QLineEdit(self.Panel3)
        self.txt10_p3.setGeometry(QtCore.QRect(30, 120, 60, 20))
        self.txt10_p3.setObjectName("txt10_p3")
        self.txtFold4 = QtGui.QLineEdit(self.Panel3)
        self.txtFold4.setGeometry(QtCore.QRect(240, 120, 40, 20))
        self.txtFold4.setObjectName("txtFold4")
        self.btAutoFill = QtGui.QPushButton(self.Panel3)
        self.btAutoFill.setGeometry(QtCore.QRect(130, 25, 51, 27))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btAutoFill.setFont(font)
        self.btAutoFill.setObjectName("btAutoFill")
        self.label29 = QtGui.QLabel(self.Panel3)
        self.label29.setGeometry(QtCore.QRect(80, 30, 51, 17))
        self.label29.setObjectName("label29")
        self.label30 = QtGui.QLabel(self.Panel3)
        self.label30.setGeometry(QtCore.QRect(240, 30, 61, 17))
        self.label30.setObjectName("label30")
        self.cbDiagFoldType = QtGui.QComboBox(self.Panel3)
        self.cbDiagFoldType.setGeometry(QtCore.QRect(300, 25, 71, 30))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.cbDiagFoldType.setFont(font)
        self.cbDiagFoldType.setObjectName("cbDiagFoldType")
        self.cbDiagFoldType.addItem("")
        self.cbDiagFoldType.addItem("")
        self.cbDiagFoldType.addItem("")
        self.cbDiagFoldType.addItem("")
        self.label31 = QtGui.QLabel(self.Panel3)
        self.label31.setGeometry(QtCore.QRect(390, 30, 81, 17))
        self.label31.setObjectName("label31")
        self.label32 = QtGui.QLabel(self.Panel3)
        self.label32.setGeometry(QtCore.QRect(500, 30, 51, 17))
        self.label32.setObjectName("label32")
        self.groupBox = QtGui.QGroupBox(self.centralwidget)
        self.groupBox.setGeometry(QtCore.QRect(10, 660, 231, 51))
        self.groupBox.setObjectName("groupBox")
        self.btDataConversion = QtGui.QPushButton(self.groupBox)
        self.btDataConversion.setGeometry(QtCore.QRect(140, 24, 81, 25))
        self.btDataConversion.setObjectName("btDataConversion")
        self.cbDataConversions = QtGui.QComboBox(self.groupBox)
        self.cbDataConversions.setGeometry(QtCore.QRect(10, 24, 111, 25))
        self.cbDataConversions.setObjectName("cbDataConversions")
        self.cbDataConversions.addItem("")
        self.cbDataConversions.addItem("")
        self.cbDataConversions.addItem("")
        self.btBack = QtGui.QToolButton(self.centralwidget)
        self.btBack.setGeometry(QtCore.QRect(260, 680, 24, 25))
        self.btBack.setArrowType(QtCore.Qt.LeftArrow)
        self.btBack.setObjectName("btBack")
        self.btForward = QtGui.QToolButton(self.centralwidget)
        self.btForward.setGeometry(QtCore.QRect(290, 680, 24, 25))
        self.btForward.setArrowType(QtCore.Qt.RightArrow)
        self.btForward.setObjectName("btForward")
        self.btSlice = QtGui.QPushButton(self.centralwidget)
        self.btSlice.setGeometry(QtCore.QRect(340, 680, 99, 27))
        self.btSlice.setObjectName("btSlice")
        self.btSlice3D = QtGui.QPushButton(self.centralwidget)
        self.btSlice3D.setGeometry(QtCore.QRect(450, 680, 99, 27))
        self.btSlice3D.setObjectName("btSlice3D")
        self.gbDataReduct = QtGui.QGroupBox(self.centralwidget)
        self.gbDataReduct.setGeometry(QtCore.QRect(10, 60, 151, 61))
        self.gbDataReduct.setObjectName("gbDataReduct")
        self.btDRExec = QtGui.QPushButton(self.gbDataReduct)
        self.btDRExec.setGeometry(QtCore.QRect(10, 26, 131, 31))
        self.btDRExec.setObjectName("btDRExec")
        self.gbExperiment = QtGui.QGroupBox(self.centralwidget)
        self.gbExperiment.setGeometry(QtCore.QRect(10, 0, 151, 61))
        self.gbExperiment.setObjectName("gbExperiment")
        self.btDataReduction = QtGui.QPushButton(self.gbExperiment)
        self.btDataReduction.setGeometry(QtCore.QRect(10, 25, 131, 31))
        self.btDataReduction.setObjectName("btDataReduction")
        self.gbOnLineBox = QtGui.QGroupBox(self.centralwidget)
        self.gbOnLineBox.setGeometry(QtCore.QRect(10, 130, 560, 91))
        self.gbOnLineBox.setObjectName("gbOnLineBox")
        self.ckAUwithReduction = QtGui.QCheckBox(self.gbOnLineBox)
        self.ckAUwithReduction.setGeometry(QtCore.QRect(170, 25, 141, 22))
        self.ckAUwithReduction.setObjectName("ckAUwithReduction")
        self.ckAUwithProjection = QtGui.QCheckBox(self.gbOnLineBox)
        self.ckAUwithProjection.setGeometry(QtCore.QRect(170, 45, 141, 22))
        self.ckAUwithProjection.setObjectName("ckAUwithProjection")
        self.ckAUwithSlice = QtGui.QCheckBox(self.gbOnLineBox)
        self.ckAUwithSlice.setGeometry(QtCore.QRect(170, 65, 141, 22))
        self.ckAUwithSlice.setObjectName("ckAUwithSlice")
        self.btAUupdate = QtGui.QPushButton(self.gbOnLineBox)
        self.btAUupdate.setGeometry(QtCore.QRect(320, 25, 99, 27))
        self.btAUupdate.setObjectName("btAUupdate")
        self.btAUstart = QtGui.QPushButton(self.gbOnLineBox)
        self.btAUstart.setGeometry(QtCore.QRect(320, 55, 111, 27))
        self.btAUstart.setObjectName("btAUstart")
        self.txAUIntervalTime = QtGui.QLineEdit(self.gbOnLineBox)
        self.txAUIntervalTime.setGeometry(QtCore.QRect(440, 55, 71, 27))
        self.txAUIntervalTime.setObjectName("txAUIntervalTime")
        self.txtAUunit = QtGui.QLabel(self.gbOnLineBox)
        self.txtAUunit.setGeometry(QtCore.QRect(520, 65, 41, 17))
        self.txtAUunit.setObjectName("txtAUunit")
        self.tgbOnLineMode = QtGui.QToolButton(self.gbOnLineBox)
        self.tgbOnLineMode.setGeometry(QtCore.QRect(10, 30, 121, 51))
        self.tgbOnLineMode.setCheckable(True)
        self.tgbOnLineMode.setObjectName("tgbOnLineMode")
        self.panel5 = QtGui.QGroupBox(self.centralwidget)
        self.panel5.setGeometry(QtCore.QRect(200, 0, 151, 61))
        self.panel5.setObjectName("panel5")
        self.btLoadData = QtGui.QPushButton(self.panel5)
        self.btLoadData.setGeometry(QtCore.QRect(9, 30, 71, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btLoadData.setFont(font)
        self.btLoadData.setObjectName("btLoadData")
        self.btSaveData = QtGui.QPushButton(self.panel5)
        self.btSaveData.setGeometry(QtCore.QRect(90, 30, 51, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btSaveData.setFont(font)
        self.btSaveData.setObjectName("btSaveData")
        self.txtExpInfo = QtGui.QLabel(self.centralwidget)
        self.txtExpInfo.setGeometry(QtCore.QRect(190, 90, 381, 41))
        self.txtExpInfo.setText("")
        self.txtExpInfo.setObjectName("txtExpInfo")
        self.txtRunNo = QtGui.QLabel(self.centralwidget)
        self.txtRunNo.setGeometry(QtCore.QRect(250, 70, 311, 20))
        self.txtRunNo.setText("")
        self.txtRunNo.setObjectName("txtRunNo")
        self.label = QtGui.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(180, 70, 68, 20))
        self.label.setObjectName("label")
        self.panel5_2 = QtGui.QGroupBox(self.centralwidget)
        self.panel5_2.setGeometry(QtCore.QRect(370, 10, 201, 51))
        self.panel5_2.setObjectName("panel5_2")
        self.btLoadXtalParam = QtGui.QPushButton(self.panel5_2)
        self.btLoadXtalParam.setGeometry(QtCore.QRect(10, 24, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btLoadXtalParam.setFont(font)
        self.btLoadXtalParam.setObjectName("btLoadXtalParam")
        self.btSaveXtalParam = QtGui.QPushButton(self.panel5_2)
        self.btSaveXtalParam.setGeometry(QtCore.QRect(70, 24, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btSaveXtalParam.setFont(font)
        self.btSaveXtalParam.setObjectName("btSaveXtalParam")
        self.btAdvXtalParam = QtGui.QPushButton(self.panel5_2)
        self.btAdvXtalParam.setGeometry(QtCore.QRect(140, 24, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btAdvXtalParam.setFont(font)
        self.btAdvXtalParam.setObjectName("btAdvXtalParam")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 585, 28))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.btDataReduction, self.tgbOnLineMode)
        MainWindow.setTabOrder(self.tgbOnLineMode, self.ckAUwithReduction)
        MainWindow.setTabOrder(self.ckAUwithReduction, self.ckAUwithProjection)
        MainWindow.setTabOrder(self.ckAUwithProjection, self.ckAUwithSlice)
        MainWindow.setTabOrder(self.ckAUwithSlice, self.btAUupdate)
        MainWindow.setTabOrder(self.btAUupdate, self.btAUstart)
        MainWindow.setTabOrder(self.btAUstart, self.txAUIntervalTime)
        MainWindow.setTabOrder(self.txAUIntervalTime, self.btDRExec)
        MainWindow.setTabOrder(self.btDRExec, self.btLoadData)
        MainWindow.setTabOrder(self.btLoadData, self.btSaveData)
        MainWindow.setTabOrder(self.btSaveData, self.txt1_p1)
        MainWindow.setTabOrder(self.txt1_p1, self.txt2_p1)
        MainWindow.setTabOrder(self.txt2_p1, self.txt3_p1)
        MainWindow.setTabOrder(self.txt3_p1, self.txt4_p1)
        MainWindow.setTabOrder(self.txt4_p1, self.txt5_p1)
        MainWindow.setTabOrder(self.txt5_p1, self.txt6_p1)
        MainWindow.setTabOrder(self.txt6_p1, self.txt7_p1)
        MainWindow.setTabOrder(self.txt7_p1, self.txt8_p1)
        MainWindow.setTabOrder(self.txt8_p1, self.txt9_p1)
        MainWindow.setTabOrder(self.txt9_p1, self.txt10_p1)
        MainWindow.setTabOrder(self.txt10_p1, self.txt11_p1)
        MainWindow.setTabOrder(self.txt11_p1, self.txt12_p1)
        MainWindow.setTabOrder(self.txt12_p1, self.chRotateAxis1st)
        MainWindow.setTabOrder(self.chRotateAxis1st, self.txt13_p1)
        MainWindow.setTabOrder(self.txt13_p1, self.chRotateAxis2nd)
        MainWindow.setTabOrder(self.chRotateAxis2nd, self.txt14_p1)
        MainWindow.setTabOrder(self.txt14_p1, self.chRotateAxis3rd)
        MainWindow.setTabOrder(self.chRotateAxis3rd, self.txt15_p1)
        MainWindow.setTabOrder(self.txt15_p1, self.txt1_p2)
        MainWindow.setTabOrder(self.txt1_p2, self.txt2_p2)
        MainWindow.setTabOrder(self.txt2_p2, self.txt3_p2)
        MainWindow.setTabOrder(self.txt3_p2, self.txt4_p2)
        MainWindow.setTabOrder(self.txt4_p2, self.txt5_p2)
        MainWindow.setTabOrder(self.txt5_p2, self.txt6_p2)
        MainWindow.setTabOrder(self.txt6_p2, self.txt7_p2)
        MainWindow.setTabOrder(self.txt7_p2, self.txt8_p2)
        MainWindow.setTabOrder(self.txt8_p2, self.txt9_p2)
        MainWindow.setTabOrder(self.txt9_p2, self.txt10_p2)
        MainWindow.setTabOrder(self.txt10_p2, self.txt11_p2)
        MainWindow.setTabOrder(self.txt11_p2, self.txt12_p2)
        MainWindow.setTabOrder(self.txt12_p2, self.txt13_p2)
        MainWindow.setTabOrder(self.txt13_p2, self.txt14_p2)
        MainWindow.setTabOrder(self.txt14_p2, self.txt15_p2)
        MainWindow.setTabOrder(self.txt15_p2, self.txt16_p2)
        MainWindow.setTabOrder(self.txt16_p2, self.txt17_p2)
        MainWindow.setTabOrder(self.txt17_p2, self.txt18_p2)
        MainWindow.setTabOrder(self.txt18_p2, self.txt19_p2)
        MainWindow.setTabOrder(self.txt19_p2, self.txt20_p2)
        MainWindow.setTabOrder(self.txt20_p2, self.txt21_p2)
        MainWindow.setTabOrder(self.txt21_p2, self.txt22_p2)
        MainWindow.setTabOrder(self.txt22_p2, self.txt23_p2)
        MainWindow.setTabOrder(self.txt23_p2, self.txt24_p2)
        MainWindow.setTabOrder(self.txt24_p2, self.btProjectionClear)
        MainWindow.setTabOrder(self.btProjectionClear, self.btProjectionAll)
        MainWindow.setTabOrder(self.btProjectionAll, self.btAutoFill)
        MainWindow.setTabOrder(self.btAutoFill, self.cbDiagFoldType)
        MainWindow.setTabOrder(self.cbDiagFoldType, self.txt1_p3)
        MainWindow.setTabOrder(self.txt1_p3, self.txt2_p3)
        MainWindow.setTabOrder(self.txt2_p3, self.btAutoFillAx1)
        MainWindow.setTabOrder(self.btAutoFillAx1, self.txtFold1)
        MainWindow.setTabOrder(self.txtFold1, self.kbUseAx1Fold)
        MainWindow.setTabOrder(self.kbUseAx1Fold, self.v1ch)
        MainWindow.setTabOrder(self.v1ch, self.txt3_p3)
        MainWindow.setTabOrder(self.txt3_p3, self.txt4_p3)
        MainWindow.setTabOrder(self.txt4_p3, self.txt5_p3)
        MainWindow.setTabOrder(self.txt5_p3, self.btAutoFillAx2)
        MainWindow.setTabOrder(self.btAutoFillAx2, self.txtFold2)
        MainWindow.setTabOrder(self.txtFold2, self.kbUseAx2Fold)
        MainWindow.setTabOrder(self.kbUseAx2Fold, self.v2ch)
        MainWindow.setTabOrder(self.v2ch, self.txt6_p3)
        MainWindow.setTabOrder(self.txt6_p3, self.txt7_p3)
        MainWindow.setTabOrder(self.txt7_p3, self.txt8_p3)
        MainWindow.setTabOrder(self.txt8_p3, self.btAutoFillAx3)
        MainWindow.setTabOrder(self.btAutoFillAx3, self.txtFold3)
        MainWindow.setTabOrder(self.txtFold3, self.kbUseAx3Fold)
        MainWindow.setTabOrder(self.kbUseAx3Fold, self.v3ch)
        MainWindow.setTabOrder(self.v3ch, self.txt9_p3)
        MainWindow.setTabOrder(self.txt9_p3, self.txt10_p3)
        MainWindow.setTabOrder(self.txt10_p3, self.txt11_p3)
        MainWindow.setTabOrder(self.txt11_p3, self.btAutoFillAx4)
        MainWindow.setTabOrder(self.btAutoFillAx4, self.txtFold4)
        MainWindow.setTabOrder(self.txtFold4, self.kbUseAx4Fold)
        MainWindow.setTabOrder(self.kbUseAx4Fold, self.v4ch)
        MainWindow.setTabOrder(self.v4ch, self.txt12_p3)
        MainWindow.setTabOrder(self.txt12_p3, self.btSlice)
        MainWindow.setTabOrder(self.btSlice, self.btSlice3D)
        MainWindow.setTabOrder(self.btSlice3D, self.btForward)
        MainWindow.setTabOrder(self.btForward, self.btBack)
        MainWindow.setTabOrder(self.btBack, self.cbDataConversions)
        MainWindow.setTabOrder(self.cbDataConversions, self.btDataConversion)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "D4Mat2Slicer Main", None, QtGui.QApplication.UnicodeUTF8))
        self.Panel1.setTitle(QtGui.QApplication.translate("MainWindow", "Sample Information", None, QtGui.QApplication.UnicodeUTF8))
        self.label15.setText(QtGui.QApplication.translate("MainWindow", "Rotation", None, QtGui.QApplication.UnicodeUTF8))
        self.label7.setText(QtGui.QApplication.translate("MainWindow", "beta:", None, QtGui.QApplication.UnicodeUTF8))
        self.label4.setText(QtGui.QApplication.translate("MainWindow", "b (Ang):", None, QtGui.QApplication.UnicodeUTF8))
        self.label6.setText(QtGui.QApplication.translate("MainWindow", "alpha:", None, QtGui.QApplication.UnicodeUTF8))
        self.label14.setText(QtGui.QApplication.translate("MainWindow", "Vl:", None, QtGui.QApplication.UnicodeUTF8))
        self.label18.setText(QtGui.QApplication.translate("MainWindow", "3rd:", None, QtGui.QApplication.UnicodeUTF8))
        self.label8.setText(QtGui.QApplication.translate("MainWindow", "gamma:", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis3rd.setItemText(1, QtGui.QApplication.translate("MainWindow", "Y", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis3rd.setItemText(2, QtGui.QApplication.translate("MainWindow", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis3rd.setItemText(3, QtGui.QApplication.translate("MainWindow", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label17.setText(QtGui.QApplication.translate("MainWindow", "2nd:", None, QtGui.QApplication.UnicodeUTF8))
        self.label11.setText(QtGui.QApplication.translate("MainWindow", "Ul:", None, QtGui.QApplication.UnicodeUTF8))
        self.label10.setText(QtGui.QApplication.translate("MainWindow", "Uk:", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis2nd.setItemText(1, QtGui.QApplication.translate("MainWindow", "Y", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis2nd.setItemText(2, QtGui.QApplication.translate("MainWindow", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis2nd.setItemText(3, QtGui.QApplication.translate("MainWindow", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label13.setText(QtGui.QApplication.translate("MainWindow", "Vk:", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis1st.setItemText(1, QtGui.QApplication.translate("MainWindow", "Y", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis1st.setItemText(2, QtGui.QApplication.translate("MainWindow", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.chRotateAxis1st.setItemText(3, QtGui.QApplication.translate("MainWindow", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label3.setText(QtGui.QApplication.translate("MainWindow", "a (Ang):", None, QtGui.QApplication.UnicodeUTF8))
        self.label16.setText(QtGui.QApplication.translate("MainWindow", "1st:", None, QtGui.QApplication.UnicodeUTF8))
        self.label5.setText(QtGui.QApplication.translate("MainWindow", "c (Ang):", None, QtGui.QApplication.UnicodeUTF8))
        self.label9.setText(QtGui.QApplication.translate("MainWindow", "Uh:", None, QtGui.QApplication.UnicodeUTF8))
        self.label12.setText(QtGui.QApplication.translate("MainWindow", "Vh:", None, QtGui.QApplication.UnicodeUTF8))
        self.Panel2.setTitle(QtGui.QApplication.translate("MainWindow", "Projection", None, QtGui.QApplication.UnicodeUTF8))
        self.label25.setText(QtGui.QApplication.translate("MainWindow", "ax1:", None, QtGui.QApplication.UnicodeUTF8))
        self.label26.setText(QtGui.QApplication.translate("MainWindow", "ax2:", None, QtGui.QApplication.UnicodeUTF8))
        self.label27.setText(QtGui.QApplication.translate("MainWindow", "ax3:", None, QtGui.QApplication.UnicodeUTF8))
        self.label28.setText(QtGui.QApplication.translate("MainWindow", "ax4:", None, QtGui.QApplication.UnicodeUTF8))
        self.label19.setText(QtGui.QApplication.translate("MainWindow", "a*", None, QtGui.QApplication.UnicodeUTF8))
        self.label20.setText(QtGui.QApplication.translate("MainWindow", "b*", None, QtGui.QApplication.UnicodeUTF8))
        self.label21.setText(QtGui.QApplication.translate("MainWindow", "c*", None, QtGui.QApplication.UnicodeUTF8))
        self.label23.setText(QtGui.QApplication.translate("MainWindow", "Energy", None, QtGui.QApplication.UnicodeUTF8))
        self.label24.setText(QtGui.QApplication.translate("MainWindow", "Axis Label", None, QtGui.QApplication.UnicodeUTF8))
        self.btProjectionAll.setText(QtGui.QApplication.translate("MainWindow", "Projection", None, QtGui.QApplication.UnicodeUTF8))
        self.btProjectionClear.setText(QtGui.QApplication.translate("MainWindow", "Clear", None, QtGui.QApplication.UnicodeUTF8))
        self.label24_2.setText(QtGui.QApplication.translate("MainWindow", "Unit", None, QtGui.QApplication.UnicodeUTF8))
        self.Panel3.setTitle(QtGui.QApplication.translate("MainWindow", "Slicing", None, QtGui.QApplication.UnicodeUTF8))
        self.label33.setText(QtGui.QApplication.translate("MainWindow", "ax1:", None, QtGui.QApplication.UnicodeUTF8))
        self.label34.setText(QtGui.QApplication.translate("MainWindow", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFillAx1.setText(QtGui.QApplication.translate("MainWindow", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.kbUseAx1Fold.setText(QtGui.QApplication.translate("MainWindow", "used", None, QtGui.QApplication.UnicodeUTF8))
        self.v1ch.setItemText(0, QtGui.QApplication.translate("MainWindow", "X-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v1ch.setItemText(1, QtGui.QApplication.translate("MainWindow", "Y-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v1ch.setItemText(2, QtGui.QApplication.translate("MainWindow", "Thickness", None, QtGui.QApplication.UnicodeUTF8))
        self.v1ch.setItemText(3, QtGui.QApplication.translate("MainWindow", "Z-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFillAx2.setText(QtGui.QApplication.translate("MainWindow", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.kbUseAx2Fold.setText(QtGui.QApplication.translate("MainWindow", "used", None, QtGui.QApplication.UnicodeUTF8))
        self.label36.setText(QtGui.QApplication.translate("MainWindow", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.v2ch.setItemText(0, QtGui.QApplication.translate("MainWindow", "X-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v2ch.setItemText(1, QtGui.QApplication.translate("MainWindow", "Y-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v2ch.setItemText(2, QtGui.QApplication.translate("MainWindow", "Thickness", None, QtGui.QApplication.UnicodeUTF8))
        self.v2ch.setItemText(3, QtGui.QApplication.translate("MainWindow", "Z-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.label35.setText(QtGui.QApplication.translate("MainWindow", "ax2:", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFillAx3.setText(QtGui.QApplication.translate("MainWindow", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.kbUseAx3Fold.setText(QtGui.QApplication.translate("MainWindow", "used", None, QtGui.QApplication.UnicodeUTF8))
        self.label38.setText(QtGui.QApplication.translate("MainWindow", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.v3ch.setItemText(0, QtGui.QApplication.translate("MainWindow", "X-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v3ch.setItemText(1, QtGui.QApplication.translate("MainWindow", "Y-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v3ch.setItemText(2, QtGui.QApplication.translate("MainWindow", "Thickness", None, QtGui.QApplication.UnicodeUTF8))
        self.v3ch.setItemText(3, QtGui.QApplication.translate("MainWindow", "Z-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.label37.setText(QtGui.QApplication.translate("MainWindow", "ax3:", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFillAx4.setText(QtGui.QApplication.translate("MainWindow", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.kbUseAx4Fold.setText(QtGui.QApplication.translate("MainWindow", "used", None, QtGui.QApplication.UnicodeUTF8))
        self.label40.setText(QtGui.QApplication.translate("MainWindow", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.v4ch.setItemText(0, QtGui.QApplication.translate("MainWindow", "X-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v4ch.setItemText(1, QtGui.QApplication.translate("MainWindow", "Y-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.v4ch.setItemText(2, QtGui.QApplication.translate("MainWindow", "Thickness", None, QtGui.QApplication.UnicodeUTF8))
        self.v4ch.setItemText(3, QtGui.QApplication.translate("MainWindow", "Z-Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.label39.setText(QtGui.QApplication.translate("MainWindow", "ax4:", None, QtGui.QApplication.UnicodeUTF8))
        self.btAutoFill.setText(QtGui.QApplication.translate("MainWindow", "Auto", None, QtGui.QApplication.UnicodeUTF8))
        self.label29.setText(QtGui.QApplication.translate("MainWindow", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label30.setText(QtGui.QApplication.translate("MainWindow", "Folding", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDiagFoldType.setItemText(0, QtGui.QApplication.translate("MainWindow", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDiagFoldType.setItemText(1, QtGui.QApplication.translate("MainWindow", "X > Y", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDiagFoldType.setItemText(2, QtGui.QApplication.translate("MainWindow", "X > -Y", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDiagFoldType.setItemText(3, QtGui.QApplication.translate("MainWindow", "Both", None, QtGui.QApplication.UnicodeUTF8))
        self.label31.setText(QtGui.QApplication.translate("MainWindow", "Plot Axis", None, QtGui.QApplication.UnicodeUTF8))
        self.label32.setText(QtGui.QApplication.translate("MainWindow", "Step", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("MainWindow", "Data Conversion", None, QtGui.QApplication.UnicodeUTF8))
        self.btDataConversion.setText(QtGui.QApplication.translate("MainWindow", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDataConversions.setItemText(0, QtGui.QApplication.translate("MainWindow", "D4Mat", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDataConversions.setItemText(1, QtGui.QApplication.translate("MainWindow", "SPE", None, QtGui.QApplication.UnicodeUTF8))
        self.cbDataConversions.setItemText(2, QtGui.QApplication.translate("MainWindow", "NxSPE", None, QtGui.QApplication.UnicodeUTF8))
        self.btBack.setText(QtGui.QApplication.translate("MainWindow", "...", None, QtGui.QApplication.UnicodeUTF8))
        self.btForward.setText(QtGui.QApplication.translate("MainWindow", "...", None, QtGui.QApplication.UnicodeUTF8))
        self.btSlice.setText(QtGui.QApplication.translate("MainWindow", "Slice", None, QtGui.QApplication.UnicodeUTF8))
        self.btSlice3D.setText(QtGui.QApplication.translate("MainWindow", "3D Slice", None, QtGui.QApplication.UnicodeUTF8))
        self.gbDataReduct.setTitle(QtGui.QApplication.translate("MainWindow", "Data Reduction", None, QtGui.QApplication.UnicodeUTF8))
        self.btDRExec.setText(QtGui.QApplication.translate("MainWindow", "Execute", None, QtGui.QApplication.UnicodeUTF8))
        self.gbExperiment.setTitle(QtGui.QApplication.translate("MainWindow", "Experiment", None, QtGui.QApplication.UnicodeUTF8))
        self.btDataReduction.setText(QtGui.QApplication.translate("MainWindow", "Setting", None, QtGui.QApplication.UnicodeUTF8))
        self.gbOnLineBox.setTitle(QtGui.QApplication.translate("MainWindow", "Online Data Reduction", None, QtGui.QApplication.UnicodeUTF8))
        self.ckAUwithReduction.setText(QtGui.QApplication.translate("MainWindow", "with Reduction", None, QtGui.QApplication.UnicodeUTF8))
        self.ckAUwithProjection.setText(QtGui.QApplication.translate("MainWindow", "with Projection", None, QtGui.QApplication.UnicodeUTF8))
        self.ckAUwithSlice.setText(QtGui.QApplication.translate("MainWindow", "with Slice", None, QtGui.QApplication.UnicodeUTF8))
        self.btAUupdate.setText(QtGui.QApplication.translate("MainWindow", "Update", None, QtGui.QApplication.UnicodeUTF8))
        self.btAUstart.setText(QtGui.QApplication.translate("MainWindow", "Interval Start", None, QtGui.QApplication.UnicodeUTF8))
        self.txtAUunit.setText(QtGui.QApplication.translate("MainWindow", "[sec]", None, QtGui.QApplication.UnicodeUTF8))
        self.tgbOnLineMode.setText(QtGui.QApplication.translate("MainWindow", "On-Line Mode", None, QtGui.QApplication.UnicodeUTF8))
        self.panel5.setTitle(QtGui.QApplication.translate("MainWindow", "D4Mat2 File ...", None, QtGui.QApplication.UnicodeUTF8))
        self.btLoadData.setText(QtGui.QApplication.translate("MainWindow", "Load", None, QtGui.QApplication.UnicodeUTF8))
        self.btSaveData.setText(QtGui.QApplication.translate("MainWindow", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("MainWindow", "RunNo :", None, QtGui.QApplication.UnicodeUTF8))
        self.panel5_2.setTitle(QtGui.QApplication.translate("MainWindow", "XtalParam File ...", None, QtGui.QApplication.UnicodeUTF8))
        self.btLoadXtalParam.setText(QtGui.QApplication.translate("MainWindow", "Load", None, QtGui.QApplication.UnicodeUTF8))
        self.btSaveXtalParam.setText(QtGui.QApplication.translate("MainWindow", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.btAdvXtalParam.setText(QtGui.QApplication.translate("MainWindow", "Partial", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'D4mat2SlicerQ_Sub.ui'
#
# Created: Mon Aug 30 22:13:35 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DataReductionPanel(object):
    def setupUi(self, DataReductionPanel):
        DataReductionPanel.setObjectName("DataReductionPanel")
        DataReductionPanel.resize(521, 843)
        self.centralwidget = QtGui.QWidget(DataReductionPanel)
        self.centralwidget.setObjectName("centralwidget")
        self.groupBox = QtGui.QGroupBox(self.centralwidget)
        self.groupBox.setGeometry(QtCore.QRect(10, 0, 361, 51))
        self.groupBox.setObjectName("groupBox")
        self.rbContRotMethod = QtGui.QRadioButton(self.groupBox)
        self.rbContRotMethod.setGeometry(QtCore.QRect(10, 25, 117, 22))
        self.rbContRotMethod.setObjectName("rbContRotMethod")
        self.rbStepByStepMethod = QtGui.QRadioButton(self.groupBox)
        self.rbStepByStepMethod.setGeometry(QtCore.QRect(220, 25, 117, 22))
        self.rbStepByStepMethod.setObjectName("rbStepByStepMethod")
        self.groupBox_2 = QtGui.QGroupBox(self.centralwidget)
        self.groupBox_2.setGeometry(QtCore.QRect(10, 50, 501, 61))
        self.groupBox_2.setObjectName("groupBox_2")
        self.txtEi = QtGui.QLineEdit(self.groupBox_2)
        self.txtEi.setGeometry(QtCore.QRect(40, 30, 71, 25))
        self.txtEi.setObjectName("txtEi")
        self.txtEnergyBin = QtGui.QLineEdit(self.groupBox_2)
        self.txtEnergyBin.setGeometry(QtCore.QRect(180, 30, 61, 25))
        self.txtEnergyBin.setObjectName("txtEnergyBin")
        self.txtEnergyMin = QtGui.QLineEdit(self.groupBox_2)
        self.txtEnergyMin.setGeometry(QtCore.QRect(330, 30, 61, 25))
        self.txtEnergyMin.setObjectName("txtEnergyMin")
        self.txtEnergyMax = QtGui.QLineEdit(self.groupBox_2)
        self.txtEnergyMax.setGeometry(QtCore.QRect(420, 30, 61, 25))
        self.txtEnergyMax.setObjectName("txtEnergyMax")
        self.label = QtGui.QLabel(self.groupBox_2)
        self.label.setGeometry(QtCore.QRect(10, 30, 68, 25))
        self.label.setObjectName("label")
        self.label_2 = QtGui.QLabel(self.groupBox_2)
        self.label_2.setGeometry(QtCore.QRect(120, 30, 68, 25))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtGui.QLabel(self.groupBox_2)
        self.label_3.setGeometry(QtCore.QRect(250, 30, 81, 25))
        self.label_3.setObjectName("label_3")
        self.label_4 = QtGui.QLabel(self.groupBox_2)
        self.label_4.setGeometry(QtCore.QRect(390, 30, 31, 25))
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName("label_4")
        self.groupBox_3 = QtGui.QGroupBox(self.centralwidget)
        self.groupBox_3.setGeometry(QtCore.QRect(10, 110, 501, 51))
        self.groupBox_3.setObjectName("groupBox_3")
        self.txMaskFilePath = QtGui.QLineEdit(self.groupBox_3)
        self.txMaskFilePath.setGeometry(QtCore.QRect(20, 25, 381, 20))
        self.txMaskFilePath.setObjectName("txMaskFilePath")
        self.btSelectMaskFile = QtGui.QPushButton(self.groupBox_3)
        self.btSelectMaskFile.setGeometry(QtCore.QRect(420, 25, 61, 25))
        self.btSelectMaskFile.setObjectName("btSelectMaskFile")
        self.groupBox_4 = QtGui.QGroupBox(self.centralwidget)
        self.groupBox_4.setGeometry(QtCore.QRect(10, 250, 501, 71))
        self.groupBox_4.setObjectName("groupBox_4")
        self.rbUseDRDefault = QtGui.QRadioButton(self.groupBox_4)
        self.rbUseDRDefault.setGeometry(QtCore.QRect(10, 20, 117, 22))
        self.rbUseDRDefault.setObjectName("rbUseDRDefault")
        self.rbUseDRScript = QtGui.QRadioButton(self.groupBox_4)
        self.rbUseDRScript.setGeometry(QtCore.QRect(100, 20, 101, 22))
        self.rbUseDRScript.setObjectName("rbUseDRScript")
        self.btMakeDRTemp = QtGui.QPushButton(self.groupBox_4)
        self.btMakeDRTemp.setGeometry(QtCore.QRect(230, 20, 71, 27))
        self.btMakeDRTemp.setObjectName("btMakeDRTemp")
        self.btSelectDRScript = QtGui.QPushButton(self.groupBox_4)
        self.btSelectDRScript.setGeometry(QtCore.QRect(360, 20, 71, 27))
        self.btSelectDRScript.setObjectName("btSelectDRScript")
        self.label_5 = QtGui.QLabel(self.groupBox_4)
        self.label_5.setGeometry(QtCore.QRect(70, 50, 68, 17))
        self.label_5.setObjectName("label_5")
        self.lbDRScriptPath = QtGui.QLabel(self.groupBox_4)
        self.lbDRScriptPath.setGeometry(QtCore.QRect(130, 50, 351, 20))
        self.lbDRScriptPath.setText("")
        self.lbDRScriptPath.setObjectName("lbDRScriptPath")
        self.gbContRotMethod = QtGui.QGroupBox(self.centralwidget)
        self.gbContRotMethod.setGeometry(QtCore.QRect(20, 330, 231, 451))
        self.gbContRotMethod.setObjectName("gbContRotMethod")
        self.groupBox_7 = QtGui.QGroupBox(self.gbContRotMethod)
        self.groupBox_7.setGeometry(QtCore.QRect(10, 30, 211, 61))
        self.groupBox_7.setObjectName("groupBox_7")
        self.label_6 = QtGui.QLabel(self.groupBox_7)
        self.label_6.setGeometry(QtCore.QRect(10, 23, 68, 25))
        self.label_6.setObjectName("label_6")
        self.txtRunNo = QtGui.QLineEdit(self.groupBox_7)
        self.txtRunNo.setGeometry(QtCore.QRect(80, 25, 81, 25))
        self.txtRunNo.setObjectName("txtRunNo")
        self.groupBox_8 = QtGui.QGroupBox(self.gbContRotMethod)
        self.groupBox_8.setGeometry(QtCore.QRect(10, 100, 211, 151))
        self.groupBox_8.setObjectName("groupBox_8")
        self.label_7 = QtGui.QLabel(self.groupBox_8)
        self.label_7.setGeometry(QtCore.QRect(10, 28, 81, 25))
        self.label_7.setObjectName("label_7")
        self.label_8 = QtGui.QLabel(self.groupBox_8)
        self.label_8.setGeometry(QtCore.QRect(10, 90, 81, 25))
        self.label_8.setObjectName("label_8")
        self.label_9 = QtGui.QLabel(self.groupBox_8)
        self.label_9.setGeometry(QtCore.QRect(10, 120, 81, 25))
        self.label_9.setObjectName("label_9")
        self.txtStartDeg = QtGui.QLineEdit(self.groupBox_8)
        self.txtStartDeg.setGeometry(QtCore.QRect(110, 30, 81, 25))
        self.txtStartDeg.setObjectName("txtStartDeg")
        self.txtMaxDeg = QtGui.QLineEdit(self.groupBox_8)
        self.txtMaxDeg.setGeometry(QtCore.QRect(110, 90, 81, 25))
        self.txtMaxDeg.setObjectName("txtMaxDeg")
        self.txtStepDeg = QtGui.QLineEdit(self.groupBox_8)
        self.txtStepDeg.setGeometry(QtCore.QRect(110, 120, 81, 25))
        self.txtStepDeg.setObjectName("txtStepDeg")
        self.label_16 = QtGui.QLabel(self.groupBox_8)
        self.label_16.setGeometry(QtCore.QRect(10, 60, 81, 25))
        self.label_16.setObjectName("label_16")
        self.txtMinDeg = QtGui.QLineEdit(self.groupBox_8)
        self.txtMinDeg.setGeometry(QtCore.QRect(110, 60, 81, 25))
        self.txtMinDeg.setObjectName("txtMinDeg")
        self.groupBox_9 = QtGui.QGroupBox(self.gbContRotMethod)
        self.groupBox_9.setGeometry(QtCore.QRect(10, 260, 211, 91))
        self.groupBox_9.setObjectName("groupBox_9")
        self.label_10 = QtGui.QLabel(self.groupBox_9)
        self.label_10.setGeometry(QtCore.QRect(20, 28, 71, 25))
        self.label_10.setObjectName("label_10")
        self.label_11 = QtGui.QLabel(self.groupBox_9)
        self.label_11.setGeometry(QtCore.QRect(20, 53, 68, 25))
        self.label_11.setObjectName("label_11")
        self.txtTimeSliceStart = QtGui.QLineEdit(self.groupBox_9)
        self.txtTimeSliceStart.setGeometry(QtCore.QRect(110, 30, 81, 25))
        self.txtTimeSliceStart.setObjectName("txtTimeSliceStart")
        self.txtTimeSliceEnd = QtGui.QLineEdit(self.groupBox_9)
        self.txtTimeSliceEnd.setGeometry(QtCore.QRect(110, 55, 81, 25))
        self.txtTimeSliceEnd.setObjectName("txtTimeSliceEnd")
        self.gbTrigNETinfo = QtGui.QGroupBox(self.gbContRotMethod)
        self.gbTrigNETinfo.setGeometry(QtCore.QRect(10, 360, 211, 81))
        self.gbTrigNETinfo.setObjectName("gbTrigNETinfo")
        self.txtTrigNETdaqId = QtGui.QLineEdit(self.gbTrigNETinfo)
        self.txtTrigNETdaqId.setGeometry(QtCore.QRect(10, 50, 31, 25))
        self.txtTrigNETdaqId.setObjectName("txtTrigNETdaqId")
        self.txtTrigNETmodNo = QtGui.QLineEdit(self.gbTrigNETinfo)
        self.txtTrigNETmodNo.setGeometry(QtCore.QRect(70, 50, 31, 25))
        self.txtTrigNETmodNo.setObjectName("txtTrigNETmodNo")
        self.cbTrigNETinfoIO = QtGui.QComboBox(self.gbTrigNETinfo)
        self.cbTrigNETinfoIO.setGeometry(QtCore.QRect(120, 50, 81, 25))
        self.cbTrigNETinfoIO.setObjectName("cbTrigNETinfoIO")
        self.cbTrigNETinfoIO.addItem("")
        self.cbTrigNETinfoIO.addItem("")
        self.cbTrigNETinfoIO.addItem("")
        self.cbTrigNETinfoIO.addItem("")
        self.cbTrigNETinfoIO.addItem("")
        self.cbTrigNETinfoIO.addItem("")
        self.cbTrigNETinfoIO.addItem("")
        self.cbTrigNETinfoIO.addItem("")
        self.label_17 = QtGui.QLabel(self.gbTrigNETinfo)
        self.label_17.setGeometry(QtCore.QRect(10, 30, 61, 17))
        self.label_17.setObjectName("label_17")
        self.label_18 = QtGui.QLabel(self.gbTrigNETinfo)
        self.label_18.setGeometry(QtCore.QRect(60, 30, 61, 17))
        self.label_18.setObjectName("label_18")
        self.label_19 = QtGui.QLabel(self.gbTrigNETinfo)
        self.label_19.setGeometry(QtCore.QRect(130, 30, 67, 17))
        self.label_19.setObjectName("label_19")
        self.gbStepByStepMethod = QtGui.QGroupBox(self.centralwidget)
        self.gbStepByStepMethod.setGeometry(QtCore.QRect(260, 330, 251, 411))
        self.gbStepByStepMethod.setObjectName("gbStepByStepMethod")
        self.btLoadRunInfoFile = QtGui.QPushButton(self.gbStepByStepMethod)
        self.btLoadRunInfoFile.setGeometry(QtCore.QRect(10, 30, 121, 27))
        self.btLoadRunInfoFile.setObjectName("btLoadRunInfoFile")
        self.btClearRunInfo = QtGui.QPushButton(self.gbStepByStepMethod)
        self.btClearRunInfo.setGeometry(QtCore.QRect(180, 30, 61, 27))
        self.btClearRunInfo.setObjectName("btClearRunInfo")
        self.label_12 = QtGui.QLabel(self.gbStepByStepMethod)
        self.label_12.setGeometry(QtCore.QRect(10, 290, 111, 17))
        self.label_12.setObjectName("label_12")
        self.txtOrgAngle = QtGui.QLineEdit(self.gbStepByStepMethod)
        self.txtOrgAngle.setGeometry(QtCore.QRect(110, 290, 75, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.txtOrgAngle.setFont(font)
        self.txtOrgAngle.setObjectName("txtOrgAngle")
        self.btReCalc = QtGui.QPushButton(self.gbStepByStepMethod)
        self.btReCalc.setGeometry(QtCore.QRect(195, 285, 50, 25))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btReCalc.setFont(font)
        self.btReCalc.setObjectName("btReCalc")
        self.label_13 = QtGui.QLabel(self.gbStepByStepMethod)
        self.label_13.setGeometry(QtCore.QRect(20, 330, 68, 17))
        self.label_13.setObjectName("label_13")
        self.label_14 = QtGui.QLabel(self.gbStepByStepMethod)
        self.label_14.setGeometry(QtCore.QRect(100, 330, 41, 20))
        self.label_14.setObjectName("label_14")
        self.label_15 = QtGui.QLabel(self.gbStepByStepMethod)
        self.label_15.setGeometry(QtCore.QRect(170, 330, 91, 17))
        self.label_15.setObjectName("label_15")
        self.txtSbSRunNo = QtGui.QLineEdit(self.gbStepByStepMethod)
        self.txtSbSRunNo.setGeometry(QtCore.QRect(10, 350, 71, 25))
        self.txtSbSRunNo.setObjectName("txtSbSRunNo")
        self.txtSbSAngle = QtGui.QLineEdit(self.gbStepByStepMethod)
        self.txtSbSAngle.setGeometry(QtCore.QRect(90, 350, 71, 25))
        self.txtSbSAngle.setObjectName("txtSbSAngle")
        self.txtSbSProtons = QtGui.QLineEdit(self.gbStepByStepMethod)
        self.txtSbSProtons.setGeometry(QtCore.QRect(170, 350, 71, 25))
        self.txtSbSProtons.setObjectName("txtSbSProtons")
        self.btSbSAdd = QtGui.QPushButton(self.gbStepByStepMethod)
        self.btSbSAdd.setGeometry(QtCore.QRect(170, 380, 71, 27))
        self.btSbSAdd.setObjectName("btSbSAdd")
        self.lstRunStepInfo = QtGui.QTreeWidget(self.gbStepByStepMethod)
        self.lstRunStepInfo.setGeometry(QtCore.QRect(10, 60, 231, 221))
        self.lstRunStepInfo.setObjectName("lstRunStepInfo")
        self.lstRunStepInfo.headerItem().setText(0, "1")
        self.btDoReduction = QtGui.QPushButton(self.centralwidget)
        self.btDoReduction.setGeometry(QtCore.QRect(260, 750, 161, 31))
        self.btDoReduction.setObjectName("btDoReduction")
        self.groupBox_5 = QtGui.QGroupBox(self.centralwidget)
        self.groupBox_5.setGeometry(QtCore.QRect(10, 160, 501, 91))
        self.groupBox_5.setObjectName("groupBox_5")
        self.txtNormFactor = QtGui.QLineEdit(self.groupBox_5)
        self.txtNormFactor.setGeometry(QtCore.QRect(110, 25, 113, 25))
        self.txtNormFactor.setObjectName("txtNormFactor")
        self.label_20 = QtGui.QLabel(self.groupBox_5)
        self.label_20.setGeometry(QtCore.QRect(10, 30, 111, 17))
        self.label_20.setObjectName("label_20")
        self.label_21 = QtGui.QLabel(self.groupBox_5)
        self.label_21.setGeometry(QtCore.QRect(240, 30, 121, 17))
        self.label_21.setObjectName("label_21")
        self.txtTimeIndepBack = QtGui.QLineEdit(self.groupBox_5)
        self.txtTimeIndepBack.setGeometry(QtCore.QRect(370, 25, 113, 25))
        self.txtTimeIndepBack.setObjectName("txtTimeIndepBack")
        self.label_22 = QtGui.QLabel(self.groupBox_5)
        self.label_22.setGeometry(QtCore.QRect(10, 60, 101, 17))
        self.label_22.setObjectName("label_22")
        self.txtDetEffi = QtGui.QLineEdit(self.groupBox_5)
        self.txtDetEffi.setGeometry(QtCore.QRect(80, 60, 301, 20))
        self.txtDetEffi.setObjectName("txtDetEffi")
        DataReductionPanel.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(DataReductionPanel)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 521, 28))
        self.menubar.setObjectName("menubar")
        DataReductionPanel.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(DataReductionPanel)
        self.statusbar.setObjectName("statusbar")
        DataReductionPanel.setStatusBar(self.statusbar)

        self.retranslateUi(DataReductionPanel)
        QtCore.QMetaObject.connectSlotsByName(DataReductionPanel)
        DataReductionPanel.setTabOrder(self.rbContRotMethod, self.rbStepByStepMethod)
        DataReductionPanel.setTabOrder(self.rbStepByStepMethod, self.txtEi)
        DataReductionPanel.setTabOrder(self.txtEi, self.txtEnergyBin)
        DataReductionPanel.setTabOrder(self.txtEnergyBin, self.txtEnergyMin)
        DataReductionPanel.setTabOrder(self.txtEnergyMin, self.txtEnergyMax)
        DataReductionPanel.setTabOrder(self.txtEnergyMax, self.txMaskFilePath)
        DataReductionPanel.setTabOrder(self.txMaskFilePath, self.btSelectMaskFile)
        DataReductionPanel.setTabOrder(self.btSelectMaskFile, self.rbUseDRDefault)
        DataReductionPanel.setTabOrder(self.rbUseDRDefault, self.rbUseDRScript)
        DataReductionPanel.setTabOrder(self.rbUseDRScript, self.btMakeDRTemp)
        DataReductionPanel.setTabOrder(self.btMakeDRTemp, self.btSelectDRScript)
        DataReductionPanel.setTabOrder(self.btSelectDRScript, self.txtRunNo)
        DataReductionPanel.setTabOrder(self.txtRunNo, self.txtStartDeg)
        DataReductionPanel.setTabOrder(self.txtStartDeg, self.txtMinDeg)
        DataReductionPanel.setTabOrder(self.txtMinDeg, self.txtMaxDeg)
        DataReductionPanel.setTabOrder(self.txtMaxDeg, self.txtStepDeg)
        DataReductionPanel.setTabOrder(self.txtStepDeg, self.txtTimeSliceStart)
        DataReductionPanel.setTabOrder(self.txtTimeSliceStart, self.txtTimeSliceEnd)
        DataReductionPanel.setTabOrder(self.txtTimeSliceEnd, self.txtTrigNETdaqId)
        DataReductionPanel.setTabOrder(self.txtTrigNETdaqId, self.txtTrigNETmodNo)
        DataReductionPanel.setTabOrder(self.txtTrigNETmodNo, self.cbTrigNETinfoIO)
        DataReductionPanel.setTabOrder(self.cbTrigNETinfoIO, self.btLoadRunInfoFile)
        DataReductionPanel.setTabOrder(self.btLoadRunInfoFile, self.btClearRunInfo)
        DataReductionPanel.setTabOrder(self.btClearRunInfo, self.lstRunStepInfo)
        DataReductionPanel.setTabOrder(self.lstRunStepInfo, self.txtOrgAngle)
        DataReductionPanel.setTabOrder(self.txtOrgAngle, self.btReCalc)
        DataReductionPanel.setTabOrder(self.btReCalc, self.txtSbSRunNo)
        DataReductionPanel.setTabOrder(self.txtSbSRunNo, self.txtSbSAngle)
        DataReductionPanel.setTabOrder(self.txtSbSAngle, self.txtSbSProtons)
        DataReductionPanel.setTabOrder(self.txtSbSProtons, self.btSbSAdd)
        DataReductionPanel.setTabOrder(self.btSbSAdd, self.btDoReduction)

    def retranslateUi(self, DataReductionPanel):
        DataReductionPanel.setWindowTitle(QtGui.QApplication.translate("DataReductionPanel", "D4Mat2Slicer DataReduction", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Measurement Method", None, QtGui.QApplication.UnicodeUTF8))
        self.rbContRotMethod.setText(QtGui.QApplication.translate("DataReductionPanel", "Continuous", None, QtGui.QApplication.UnicodeUTF8))
        self.rbStepByStepMethod.setText(QtGui.QApplication.translate("DataReductionPanel", "StepByStep", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_2.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Energy Transfer Info", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DataReductionPanel", "Ei = ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DataReductionPanel", "hw bin =", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DataReductionPanel", "hw range =", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DataReductionPanel", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_3.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Mask File", None, QtGui.QApplication.UnicodeUTF8))
        self.btSelectMaskFile.setText(QtGui.QApplication.translate("DataReductionPanel", "Select", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_4.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Data Reduction Script", None, QtGui.QApplication.UnicodeUTF8))
        self.rbUseDRDefault.setText(QtGui.QApplication.translate("DataReductionPanel", "Default", None, QtGui.QApplication.UnicodeUTF8))
        self.rbUseDRScript.setText(QtGui.QApplication.translate("DataReductionPanel", "Use Script", None, QtGui.QApplication.UnicodeUTF8))
        self.btMakeDRTemp.setText(QtGui.QApplication.translate("DataReductionPanel", "Template", None, QtGui.QApplication.UnicodeUTF8))
        self.btSelectDRScript.setText(QtGui.QApplication.translate("DataReductionPanel", "Select", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DataReductionPanel", "Script :", None, QtGui.QApplication.UnicodeUTF8))
        self.gbContRotMethod.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Continuous Rotation Method", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_7.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Run Number", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("DataReductionPanel", "RunNo=", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_8.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Ocillation Info", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("DataReductionPanel", "Start Ang =", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("DataReductionPanel", "Max Ang =", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("DataReductionPanel", "Step Ang =", None, QtGui.QApplication.UnicodeUTF8))
        self.label_16.setText(QtGui.QApplication.translate("DataReductionPanel", "Min Ang =", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_9.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Time Slice", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("DataReductionPanel", "Start Sec =", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("DataReductionPanel", "End Sec =", None, QtGui.QApplication.UnicodeUTF8))
        self.gbTrigNETinfo.setTitle(QtGui.QApplication.translate("DataReductionPanel", "TrigNET Info", None, QtGui.QApplication.UnicodeUTF8))
        self.cbTrigNETinfoIO.setItemText(0, QtGui.QApplication.translate("DataReductionPanel", "DIO1", None, QtGui.QApplication.UnicodeUTF8))
        self.cbTrigNETinfoIO.setItemText(1, QtGui.QApplication.translate("DataReductionPanel", "DIO2", None, QtGui.QApplication.UnicodeUTF8))
        self.cbTrigNETinfoIO.setItemText(2, QtGui.QApplication.translate("DataReductionPanel", "DIO3", None, QtGui.QApplication.UnicodeUTF8))
        self.cbTrigNETinfoIO.setItemText(3, QtGui.QApplication.translate("DataReductionPanel", "DIO4", None, QtGui.QApplication.UnicodeUTF8))
        self.cbTrigNETinfoIO.setItemText(4, QtGui.QApplication.translate("DataReductionPanel", "DIO5", None, QtGui.QApplication.UnicodeUTF8))
        self.cbTrigNETinfoIO.setItemText(5, QtGui.QApplication.translate("DataReductionPanel", "DIO6", None, QtGui.QApplication.UnicodeUTF8))
        self.cbTrigNETinfoIO.setItemText(6, QtGui.QApplication.translate("DataReductionPanel", "DIO7", None, QtGui.QApplication.UnicodeUTF8))
        self.cbTrigNETinfoIO.setItemText(7, QtGui.QApplication.translate("DataReductionPanel", "DIO8", None, QtGui.QApplication.UnicodeUTF8))
        self.label_17.setText(QtGui.QApplication.translate("DataReductionPanel", "DaqID", None, QtGui.QApplication.UnicodeUTF8))
        self.label_18.setText(QtGui.QApplication.translate("DataReductionPanel", "ModNo", None, QtGui.QApplication.UnicodeUTF8))
        self.label_19.setText(QtGui.QApplication.translate("DataReductionPanel", "KickerIO", None, QtGui.QApplication.UnicodeUTF8))
        self.gbStepByStepMethod.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Step By Step Method", None, QtGui.QApplication.UnicodeUTF8))
        self.btLoadRunInfoFile.setText(QtGui.QApplication.translate("DataReductionPanel", "Add Run List", None, QtGui.QApplication.UnicodeUTF8))
        self.btClearRunInfo.setText(QtGui.QApplication.translate("DataReductionPanel", "Clear", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("DataReductionPanel", "Gonio at Zero :", None, QtGui.QApplication.UnicodeUTF8))
        self.btReCalc.setText(QtGui.QApplication.translate("DataReductionPanel", "Calc", None, QtGui.QApplication.UnicodeUTF8))
        self.label_13.setText(QtGui.QApplication.translate("DataReductionPanel", "RunNo", None, QtGui.QApplication.UnicodeUTF8))
        self.label_14.setText(QtGui.QApplication.translate("DataReductionPanel", "Gonio", None, QtGui.QApplication.UnicodeUTF8))
        self.label_15.setText(QtGui.QApplication.translate("DataReductionPanel", "Protons[TP]", None, QtGui.QApplication.UnicodeUTF8))
        self.btSbSAdd.setText(QtGui.QApplication.translate("DataReductionPanel", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.btDoReduction.setText(QtGui.QApplication.translate("DataReductionPanel", "Set Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_5.setTitle(QtGui.QApplication.translate("DataReductionPanel", "Other params", None, QtGui.QApplication.UnicodeUTF8))
        self.label_20.setText(QtGui.QApplication.translate("DataReductionPanel", "NormFactor = ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_21.setText(QtGui.QApplication.translate("DataReductionPanel", "TimeIndepBack =", None, QtGui.QApplication.UnicodeUTF8))
        self.label_22.setText(QtGui.QApplication.translate("DataReductionPanel", "DetEffi = ", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'D4mat2SlicerQ_XtalParam.ui'
#
# Created: Mon Aug 30 22:13:35 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_XtalParamDialog(object):
    def setupUi(self, XtalParamDialog):
        XtalParamDialog.setObjectName("XtalParamDialog")
        XtalParamDialog.resize(404, 213)
        self.rd_AllParams = QtGui.QRadioButton(XtalParamDialog)
        self.rd_AllParams.setGeometry(QtCore.QRect(20, 30, 61, 23))
        self.rd_AllParams.setChecked(True)
        self.rd_AllParams.setObjectName("rd_AllParams")
        self.rd_PartialParam = QtGui.QRadioButton(XtalParamDialog)
        self.rd_PartialParam.setGeometry(QtCore.QRect(20, 60, 81, 23))
        self.rd_PartialParam.setObjectName("rd_PartialParam")
        self.btLoadXml = QtGui.QPushButton(XtalParamDialog)
        self.btLoadXml.setGeometry(QtCore.QRect(300, 110, 89, 25))
        self.btLoadXml.setObjectName("btLoadXml")
        self.btSaveXml = QtGui.QPushButton(XtalParamDialog)
        self.btSaveXml.setGeometry(QtCore.QRect(300, 170, 89, 25))
        self.btSaveXml.setObjectName("btSaveXml")
        self.label = QtGui.QLabel(XtalParamDialog)
        self.label.setGeometry(QtCore.QRect(20, 10, 361, 17))
        self.label.setObjectName("label")
        self.groupBox = QtGui.QGroupBox(XtalParamDialog)
        self.groupBox.setGeometry(QtCore.QRect(100, 40, 171, 161))
        self.groupBox.setObjectName("groupBox")
        self.cb_LC = QtGui.QCheckBox(self.groupBox)
        self.cb_LC.setGeometry(QtCore.QRect(10, 30, 141, 23))
        self.cb_LC.setObjectName("cb_LC")
        self.cb_OR = QtGui.QCheckBox(self.groupBox)
        self.cb_OR.setGeometry(QtCore.QRect(10, 50, 151, 23))
        self.cb_OR.setObjectName("cb_OR")
        self.cb_PR = QtGui.QCheckBox(self.groupBox)
        self.cb_PR.setGeometry(QtCore.QRect(10, 70, 151, 23))
        self.cb_PR.setObjectName("cb_PR")
        self.cb_SL = QtGui.QCheckBox(self.groupBox)
        self.cb_SL.setGeometry(QtCore.QRect(10, 90, 92, 23))
        self.cb_SL.setObjectName("cb_SL")
        self.cb_DF = QtGui.QCheckBox(self.groupBox)
        self.cb_DF.setGeometry(QtCore.QRect(10, 110, 151, 23))
        self.cb_DF.setObjectName("cb_DF")
        self.cb_DR = QtGui.QCheckBox(self.groupBox)
        self.cb_DR.setGeometry(QtCore.QRect(10, 130, 141, 23))
        self.cb_DR.setObjectName("cb_DR")

        self.retranslateUi(XtalParamDialog)
        QtCore.QMetaObject.connectSlotsByName(XtalParamDialog)

    def retranslateUi(self, XtalParamDialog):
        XtalParamDialog.setWindowTitle(QtGui.QApplication.translate("XtalParamDialog", "XtalParam Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.rd_AllParams.setText(QtGui.QApplication.translate("XtalParamDialog", "All", None, QtGui.QApplication.UnicodeUTF8))
        self.rd_PartialParam.setText(QtGui.QApplication.translate("XtalParamDialog", "Partial", None, QtGui.QApplication.UnicodeUTF8))
        self.btLoadXml.setText(QtGui.QApplication.translate("XtalParamDialog", "Load", None, QtGui.QApplication.UnicodeUTF8))
        self.btSaveXml.setText(QtGui.QApplication.translate("XtalParamDialog", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("XtalParamDialog", "Save / Load the partial information of XtalParams", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("XtalParamDialog", "Information", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_LC.setText(QtGui.QApplication.translate("XtalParamDialog", "Lattice Constants", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_OR.setText(QtGui.QApplication.translate("XtalParamDialog", "Orientation", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_PR.setText(QtGui.QApplication.translate("XtalParamDialog", "Projection", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_SL.setText(QtGui.QApplication.translate("XtalParamDialog", "Slicing", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_DF.setText(QtGui.QApplication.translate("XtalParamDialog", "Diagonal folding", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_DR.setText(QtGui.QApplication.translate("XtalParamDialog", "Data Reduction", None, QtGui.QApplication.UnicodeUTF8))




#!/bin/env python
# -*- coding: utf-8 -*-
#
# Usage: runlist.py initial_run_no [final_run_no]
#    initial_run_no, final_run_no:
#       range of run numbers to be listed.
#    -np: does not show proton counts

from __future__ import print_function
from __future__ import absolute_import
import sys
import os
import glob
import Manyo as mm
import Manyo.MLF as mmlf
import Manyo.Utsusemi as mu
import utsusemi.ana.Reduction.BaseCommandsInEla as BC

ver = float(sys.version_info[0])+float(sys.version_info[1])*0.1
if ver<2.5:
    from elementtree.ElementTree import ElementTree
else:
    from xml.etree.ElementTree import ElementTree
    
#########################################
def BCMakeRunList( start_run=-1, end_run=-1, output="~/run_list.txt",flag_proton=1,offset_sec=0.0,isCT8n=True,devTemp="LS340",devGonio="Gonio" ):
    """
    Make run list 
    @param start_run (int) start run number to be listed.
    @param end_run (int) start run number to be listed.
    @param output (string) output file name
    @param flag_proton (int) 0: no protons, 1:with protons
    @param offset_sec (float) offset second for Measurement Period to get protons
    @return None
    """
    #data_folder = os.environ["UTSUSEMI_DATA_DIR"]
    #sys_name = os.environ["UTSUSEMI_SYS_NAME"]
    data_folder = mu.UtsusemiEnvGetDataDir()
    sys_name = mu.UtsusemiEnvGetInstCode()
    run_number_wild = "%s%06d_*"%(sys_name,start_run)
    import glob
    print("--- Searching run number like %s"%(run_number_wild))
    run_folder_list = glob.glob( os.path.join( data_folder, sys_name+"*" ) )
    run_folder_list.sort()
    run_folder = ""
    for a_run_folder in run_folder_list:
        run_number_list = glob.glob( os.path.join( a_run_folder, run_number_wild ) )
        if len(run_number_list)!=0:
            run_folder=a_run_folder
            break
    if run_folder=="":
        raise UserWarning( "Run folder not found :",run_folder )
    print("--- fin")
    run_number_list.sort()
    isIROHA2Used = False
    if len(run_number_list)!=0:
        fullpath = os.path.join( run_folder, run_number_list[-1],"params",("run%06d.xml"%(start_run) ) )
        if os.path.exists( fullpath ):
            isIROHA2Used = True
    
    from . import MakeRunListFromParamsIROHA2 as MR
#    if (isIROHA2Used):
#        import ana.Reduction.MakeRunListFromParamsIROHA2 as MR
#    else:
#        import ana.Reduction.MakeRunListFromParams as MR
    
    args = ["dummy"]
    if start_run<=0:
        message = "start_run must be set."
        raise UserWarning(message)
    args.append( "%d" % start_run )
    
    if end_run>0:
        args.append( "%d" % end_run )
    
    if output[:2]=="~/":
        #output = os.path.join( os.getenv("UTSUSEMI_USR_PRIV_HOME") ,output[2:] )
        output = os.path.join( mu.UtsusemiEnvGetWorkDir() ,output[2:] )
    args.append( "-f" )
    args.append( output )
    
    if flag_proton==0:
        args.append( "-np" )
    
    if isIROHA2Used:
        args.append( "-r" )
        args.append( data_folder )
        args.append( "-T" )
        args.append( devTemp )
        args.append( "-G" )
        args.append( devGonio )
        
    args.append( "-os" ) # set offset_sec 
    args.append( offset_sec )
    
    if isCT8n:
        args.append( "-CT8n" )
    
    print(args)
    
    MR.MakeRunList( args )

############################################



#########################################
def usage(argv):
    print("------------------------------------------------------------------------")
    print("Usage  %s [option] initial_run_no [final_run_no]" % (argv[0]))
    print("       initial_run_no, final_run_no : range of run numbers to be listed.")
    print("------------------------------------------------------------------------")
    print("Option")
    print("       -np          : does not show proton counts")
    print("       -f filename  : saves the list as a text file named filename")
    print("       -r directory : top directory of IROHA2 log folders, like /opt/mlfsoft/data.")
    print("------------------------------------------------------------------------")
    sys.exit(0)

#########################################
# copied from GetMeasBC.py by Y. Inamura
def GetMeasBC( runNo, flag_proton, offset_sec=0.0, isCT8Neutron=False ):
    TT = mu.T0TreatToolsNeunet()
    #st_RUNNO="%3s%06d" % (os.environ["UTSUSEMI_SYS_NAME"],runNo)
    st_RUNNO="%3s%06d" % (mu.UtsusemiEnvGetInstCode(),runNo)
    
    #root_data_dir = os.environ["UTSUSEMI_DATA_DIR"]
    #inst_code = os.environ["UTSUSEMI_SYS_NAME"]
    root_data_dir = mu.UtsusemiEnvGetDataDir()
    inst_code = mu.UtsusemiEnvGetInstCode()
    list_DATA_folder = os.listdir( root_data_dir )
    target_dir = ""    
    
    for a_DATA_folder in list_DATA_folder:
        if a_DATA_folder.find(inst_code)<0:
            continue
        
        a_path = os.path.join( root_data_dir, a_DATA_folder )
        if os.path.isdir(a_path):
            list_DATA = os.listdir( a_path )
            for a_data_dir in list_DATA:
                if a_data_dir.find( st_RUNNO )==0:
                    target_dir = os.path.join( a_path, a_data_dir )
                    break
        if target_dir!="":
            break
    
    if target_dir=="":
        err_message = "There is no data;"+st_RUNNO
        raise UserWarning(err_message)
    edb_list = os.listdir( target_dir )
    edb_list.sort()
    target_edb=""
    for a_edb in edb_list:
        if ".edb" in a_edb:
            target_edb = a_edb
            break
    if target_edb=="":
        err_message = "There is no edb data;"+st_RUNNO
        raise UserWarning(err_message)
    TT.readOrgEvent( os.path.join( target_dir, target_edb ) )
    mpv = TT.putMeasPeriodFromT0()
        
    if mpv.size()!=14:
        err_message = "False to get measuring period from Event Data"
        raise UserWarning(err_message)
    start_date = "%04d/%02d/%02d" % (int(mpv[0]),int(mpv[1]),int(mpv[2]))
    start_time = "%02d:%02d:%02d" % (int(mpv[3]),int(mpv[4]),int(mpv[5]))
    end_date   = "%04d/%02d/%02d" % (int(mpv[7]),int(mpv[8]),int(mpv[9]))
    end_time   = "%02d:%02d:%02d" % (int(mpv[10]),int(mpv[11]),int(mpv[12]))
    
    
    if flag_proton == 0:  # does not show proton counts
        proton = "     ---  "
    else:  # show proton counts
#        print "NormByBeamCurrent(runNo=%d)" % runNo
#        print "     begin date and time = ",start_date," ",start_time
#        print "       end date and time = ",end_date," ",end_time
    
        bc = BC.getBeamCurrent(start_date, start_time, end_date, end_time, offset_sec, isCT8Neutron)
        proton = "%10d" % (int(bc))

    return (runNo,start_date,start_time,end_date,end_time,proton)

#########################################
def MakeRunList(argv):
    ET = ElementTree()

    Output = [] # list where the output is stored

    # header of the output
    #Output.append("  run#           start                 end              protons     T_A    T_B     gonio")

    argc = len(argv) # number of argument
    if (argc < 2):
        usage(argv) # show help and exit

    flag_proton = 1
    offset_sec = 0.0
    # analysis arguments
    output_name=""
    data_folder="/opt/mlfsoft/data"
    devname_temp="LS340"
    devname_gonio="Gonio-1"
    init_no = -1
    fin_no = -1
    ind = 1
    isCT8Neutron = False
    while(True):
        if argv[ind]=="-np":
            flag_proton = 0
        elif argv[ind]=="-f":
            if ind==len(argv)-1:
                usage(argv)
            ind += 1
            output_name=argv[ind]
        elif argv[ind]=="-r":
            if ind==len(argv)-1:
                usage(argv)
            ind += 1
            data_folder=argv[ind]
        elif argv[ind]=="-os":
            if ind==len(argv)-1:
                usage(argv)
            ind += 1
            offset_sec=float( argv[ind] )
        elif argv[ind]=="-T":
            if ind==len(argv)-1:
                usage(argv)
            ind += 1
            devname_temp= argv[ind]
        elif argv[ind]=="-G":
            if ind==len(argv)-1:
                usage(argv)
            ind += 1
            devname_gonio= argv[ind]
        elif argv[ind]=="-CT8n": # if use CT8Neutron 
            isCT8Neutron=True
        else:
            if init_no<0:
                init_no = int(argv[ind])
            else:
                fin_no = int(argv[ind])

        ind += 1
        if ind>=len(argv):
            break

    if init_no<0:
        usage(argv)
    if fin_no<0:
        fin_no = init_no

    run_no = init_no # run number
    
    if isCT8Neutron:
        proton_source="CT8n"
    else:
        proton_source="CT9"
        
    #Output.append("  run#           start                 end          protons(%s)     T_A    T_B     gonio"%(proton_source))
    Output.append("  run#           start                 end          protons(%s)     T_A   T_D2   T_D3     gonio  kicker\ncomment"%(proton_source))
    
    #sys_name = os.environ["UTSUSEMI_SYS_NAME"]
    sys_name = mu.UtsusemiEnvGetInstCode()
    while(True):
        # xml file where the experimental condition is stored
        run_number_wild = "%s%06d_*"%(sys_name,run_no)
        run_folder_list = glob.glob( os.path.join( data_folder, sys_name+"*" ) )
        run_folder_list.sort()
        run_folder = ""
        for a_run_folder in run_folder_list:
            run_number_list = glob.glob( os.path.join( a_run_folder, run_number_wild ) )
            if len(run_number_list)!=0:
                run_folder=a_run_folder
                break
        if run_folder=="":
            raise UserWarning( "Run folder not found :",run_folder)
        
        if len(run_number_list)!=0:
            fullpath = os.path.join( run_folder, run_number_list[-1],"params",("run%06d.xml"%(run_no) ) )
            tt=mmlf.BoostXmlParser()
            tt.Load(fullpath)
            #gonio_path="runInfo/paramsList/devParam,name:%s/params/param/th"%(devname_gonio)
            #temp_path="runInfo/paramsList/devParam,name:%s/params/tmpcnt"%(devname_temp)
            runno_path="runInfo/runNo"
            runno = int( tt.PutContent(runno_path) )
            
            gonio_path="runInfo/measRslt/devLog,devName:%s/devStatus/params/param/th"%(devname_gonio)
            temp_path="runInfo/measRslt/devLog,devName:%s/devStatus/params/param"%(devname_temp)
            # read temperature
            temp_cnt = tt.PutContent(temp_path+"/temperature")
            if temp_cnt=="":
                temp = "  --- "
            else:
                temp = "%6.2f" % (float(temp_cnt))
                
            # read temperature A
            temp_a_cnt = tt.PutContent(temp_path+"/temperature_a")
            if temp_a_cnt == "":
                temp_a = "  --- "
            else:
                temp_a = "%6.2f" % (float(temp_a_cnt))

#            # read temperature B
#            temp_b_cnt = tt.PutContent(temp_path+"/temperature_b")
#            if temp_b_cnt == "":
#                temp_b = temp
#            else:
#                temp_b = "%6.2f" % (float(temp_b_cnt))
            
            # read temperature D2
            temp_d2_cnt = tt.PutContent(temp_path+"/temperature_d2")
            if temp_d2_cnt == "":
                temp_d2 = "  --- "
            else:
                temp_d2 = "%6.2f" % (float(temp_d2_cnt))
            
            # read temperature D3
            temp_d3_cnt = tt.PutContent(temp_path+"/temperature_d3")
            if temp_d3_cnt == "":
                temp_d3 = "  --- "
            else:
                temp_d3 = "%6.2f" % (float(temp_d3_cnt))
            
            # read angle of the gonio
            gonio_cnt = tt.PutContent(gonio_path)
            if gonio_cnt == "":
                gonio = "    ---    "
            else:
                gonio = "%8.4f" % (float(gonio_cnt))
            
            #temp_path="runInfo/measRslt/devLog,devName:DAQ/logs/log,compName:group2:Kicker0"
            temp_path="runInfo/measRslt/devLog,devName=DAQ/logs/log,compName=group2:Kicker0/eventNum"
            # read temperature
            kicker_cnt = tt.PutContent(temp_path)
            if kicker_cnt=="":
                kicker = "  --- "
            else:
                kicker = kicker_cnt
            
            temp_path="runInfo/comment"
            # read temperature
            comment_cnt = tt.PutContent(temp_path)
            if comment_cnt=="":
                comment = "  --- "
            else:
                comment = comment_cnt 
            del tt
            """
            # open the xml file
            e = ET.parse(open(fullpath))
            
            # read the run number from xml file to check consistency
            runno = e.find(".//runNo").text
            runno = int(runno)

            # read set temperature
            temp_el = e.find(".//temperature")
            if temp_el == None:
                temp = "  --- "
            else:
                temp = "%6.2f" % (float(temp_el.text))

            # read temperature A
            temp_a_el = e.find(".//temperature_a")
            if temp_a_el == None:
                temp_a = "set_T="
            else:
                temp_a = "%6.2f" % (float(temp_a_el.text))

            # read temperature B
            temp_b_el = e.find(".//temperature_b")
            if temp_b_el == None:
                temp_b = temp
            else:
                temp_b = "%6.2f" % (float(temp_b_el.text))

            # read angle of the gonio
            gonio_el = e.find(".//th")
            if gonio_el == None:
                gonio = "    ---    "
            else:
                gonio = "%8.4f" % (float(gonio_el.text))
            """
            
            # get proton current
            result = GetMeasBC(runno, flag_proton, offset_sec, isCT8Neutron)

            # store the output in the list
            #Output.append("%6d   %s %s   %s %s   %s   %s %s   %s" % (runno, result[1], result[2], result[3], result[4], result[5], temp_a, temp_b, gonio))
            Output.append("%6d   %s %s   %s %s   %s   %s %s %s  %s  %s\n%s" % (runno, result[1], result[2], result[3], result[4], result[5], temp_a, temp_d2, temp_d3, gonio, kicker, comment))

        run_no += 1
        if run_no > fin_no:
            break

    print() # print blank line
    print("----------------------------------------------------------------------------------------")
    for out in Output: # print the output
        print(out)
    print("----------------------------------------------------------------------------------------")
    
    # save as text file
    if output_name!="":
        print("     Output file=",output_name)
        fo = open( output_name, "w" )
        for out in Output:
            fo.write( out+"\n" )
        fo.close()
    
#########################################

if __name__ == '__main__':
    print("Input Start Run No.")
    StartRunNo = raw_input()
    print("Input End Run No.")
    EndRunNo = raw_input()

    fname = "RunListFrom%sTo%s.txt" %(StartRunNo, EndRunNo)

    BCMakeRunList(int(StartRunNo),int(EndRunNo), fname, flag_proton=1, offset_sec=0.0, isCT8n=False, devTemp="LS350Loop1", devGonio="ComCryoRotStage")



# -*- coding: utf-8 -*-
#
# $Date: 2012-08-20 17:49:07 +0900 (月, 20 8 2012) $
# $Rev: 2 $
#
from __future__ import print_function
import wx
from wx import xrc

import os

red   =(255,0  ,0  ,255)
blue  =(0  ,0  ,255,255)
green =(0  ,255,0  ,255)
white =(255,255,255,255)
black =(0  ,0  ,0  ,255)
gray  =(246,244,241,255)
yellow=(255,255,0  ,255)

class FileNotFound(Exception):
    def __init__(self, filename):
        self.filename = filename
        return

    def __str__(self):
        return repr(self.filename)

class ControlNotFound(Exception):
    def __init__(self, name):
        self.name = name
        return

    def __str__(self):
        return 'name: ' + repr(self.name)

class XrcBase(object):
    __resources = dict()

    @staticmethod
    def getResource(filename):
        fullpath = os.path.join(os.path.abspath(os.path.dirname(__file__)), '..')
        fullpath = os.path.join(fullpath, filename)

        if not os.path.exists(fullpath):
            raise FileNotFound(fullpath)

        if filename in XrcBase.__resources:
            resource = XrcBase.__resources[filename]
            pass
        else:
            resource = xrc.EmptyXmlResource()
            resource.Load(filename)
            XrcBase.__resources[filename] = resource
            pass

        return resource

    def getControl(self, name):
        control = xrc.XRCCTRL(self, name)

        #if control == None:
        #    raise ControlNotFound(name)
        return control

    def bindControl(self,name,eventhandler,callfunc):
        ctrl=self.getControl(name)
        ctrl.Bind(eventhandler,callfunc)

    def hideControl(self,name):
        ctrl=self.getControl(name)
        if ctrl!=None:
            ctrl.Hide()
        else:
            print("====",name)

    def showControl(self,name):
        ctrl=self.getControl(name)
        if ctrl!=None:
            ctrl.Show()
        else:
            print("====",name)

    def setColor(self,name,tag,colour):
        ctrl=self.getControl(name)
        if ctrl!=None:
            if tag=="fore":
                ctrl.SetForegroundColour(colour)
            elif tag=="back":
                ctrl.SetBackgroundColour(colour)
            else:
                pass
        else:
            pass

    def getColor(self,name,tag):
        ctrl=self.getControl(name)
        if ctrl!=None:
            if tag=="fore":
                return ctrl.GetForegroundColour()
            elif tag=="back":
                return ctrl.GetBackgroundColour()
            else:
                return None
        else:
            return None

    def setValue(self,name,valstr=None,valnum=None):
        ctrl=self.getControl(name)
        if valstr!=None:
            if type(valstr)==str or type(valstr)==unicode:
                pass
            else:
                valstr="---"

        if type(ctrl)==wx._controls.StaticText:
            if valstr!=None:
                ctrl.SetLabel(valstr)
        elif type(ctrl)==wx._controls.TextCtrl:
            if valstr!=None:
                ctrl.SetValue(valstr)
        elif type(ctrl)==wx._controls.Button:
            if valstr!=None:
                ctrl.SetLabel(valstr)
            if valnum!=None:
                ctrl.SetValue(valnum)
        elif type(ctrl)==wx._controls.ToggleButton:
            if valstr!=None:
                ctrl.SetLabel(valstr)
            if valnum!=None:
                ctrl.SetValue(valnum)
        elif type(ctrl)==wx._controls.Choice:
            if valnum!=None:
                ctrl.SetSelection(valnum)
        else:
            pass

    def getValue(self,name):
        ctrl=self.getControl(name)
        if type(ctrl)==wx._controls.TextCtrl:
            val=ctrl.GetValue()
        elif type(ctrl)==wx._controls.ComboBox:
            val=str(ctrl.GetSelection())
        elif type(ctrl)==wx._controls.Choice:
            val=str(ctrl.GetSelection())
        elif type(ctrl)==wx._controls.ToggleButton:
            val=ctrl.GetValue()
        else:
            print(type(ctrl),name)
            val=0
        return val


    def setControl(self, name,flag=True):
        ctrl=self.getControl(name)
        ctrl.Enable(flag)


    def unsetControl(self, name):
        ctrl=self.getControl(name)
        ctrl.Disable()

    def setBlink(self,name,color1,color2,flag):
        ctrl=self.getControl(name)
        if ctrl!=None:
            if flag=="back":
                if ctrl.GetBackgroundColour()==color1:
                    ctrl.SetBackgroundColour(color2)
                elif ctrl.GetBackgroundColour()==color2:
                    ctrl.SetBackgroundColour(color1)
                else:
                    ctrl.SetBackgroundColour(color1)
            if flag=="fore":
                if ctrl.GetForegroundColour()==color1:
                    ctrl.SetForegroundColour(color2)
                elif ctrl.GetForegroundColour()==color2:
                    ctrl.SetForegroundColour(color1)
                else:
                    ctrl.SetForegroundColour(color1)
        else:
            print(type(ctrl))

    def setNumberControl(self, name):
        obj=self.getControl(name)

        if "SetValue" in dir(obj):
            obj.Bind(wx.EVT_TEXT,self.checkNumberControl)

    def checkNumberControl(self,event):       # テキストコントロールに数字だけ入力モードにする。
        obj=event.GetEventObject()
        if type(obj)==wx._controls.TextCtrl:
            text=obj.GetValue()
            if len(text)!=0: 
                condition  = text[-1].isdigit() # isdigit
                condition += text[-1]=="."      # とりあえず可 OR
                condition += text[-1]=="+"      #           OR
                condition += text[-1]=="-"      #           OR
                condition += text[-1]=="e"      #           OR
                condition += text[-1]=="E"      #           OR
                #AND
                condition *=text.count(".")<2   # 2個以上は不可
                condition *=text.count("e")<2
                condition *=text.count("E")<2
                #AND
                if text[-1]=="+":
                    if len(text)==1:            # 最初は可
                        condition *=True
                    else:
                        ind=text[1:].index("+")
                        if text[ind]=="e" or text[ind]=="E": # Eの次でも可
                            condition *=True
                        else:
                            condition *=False
                #AND
                if text[-1]=="-":
                    if len(text)==1:            # 最初は可
                        condition *=True
                    else:
                        ind=text[1:].index("-")
                        if text[ind]=="e" or text[ind]=="E": # Eの次でも可
                            condition *=True
                        else:
                            condition *=False
                #AND
                if text[-1]==".":
                    if len(text)==1:            # 最初は可
                        condition *=True
                    else:
                        if text[-2]=="e" or text[-2]=="E": # Eの次は不可
                            condition *=False
                        else:
                            condition *=True
                #AND
                if text[-1]=="e" or text[-1]=="e":
                    if len(text)==1:            # 最初は不可
                        condition *=False
                    else:
                        if text[-2]==".": # Eの次は不可
                            condition *=False
                        else:
                            condition *=True

                if condition > 0:
                    pass
                else:
                    if len(text)!=0:
                        obj.SetValue(text[:-1])


class FrameBase(XrcBase, wx.Frame):
    def __init__(self, filename, frameName):
        resource = XrcBase.getResource(filename)

        pre = wx.PreFrame()
        resource.LoadOnFrame(pre, None, frameName)
        self.PostCreate(pre)
        return

class DialogBase(XrcBase, wx.Dialog):
    def __init__(self, parent, filename, dialogName):
        resource = XrcBase.getResource(filename)

        pre = wx.PreDialog()
        resource.LoadOnDialog(pre, parent, dialogName)
        self.PostCreate(pre)
        self.CenterOnParent()
        return

class PanelBase(XrcBase, wx.Panel):
    def __init__(self, parent, filename, panelName):
        resource = XrcBase.getResource(filename)

        pre = wx.PrePanel()
        resource.LoadOnPanel(pre, parent, panelName)
        self.PostCreate(pre)
        return



# -*- coding: utf-8 -*-
import wx
from matplotlib.backends.backend_wx import NavigationToolbar2Wx
from vis.UtilPlot import IFEvtProp, Images

#######################################
#  ChartToolBar
#######################################         
class ChartToolBar(NavigationToolbar2Wx, wx.ToolBar):
    """
    matplotlib 画像操作用のツールバーの拡張クラス
    印刷処理追加と、画面設定処理のオーバーライド
    """
    #######################################
    def __init__(self, parent, order):
        """
        コンストラクタ
        @param parent  親クラスのインスタンス
        @params order  イベントディスパッチャのID
        @retval 無
        """
        self.parent = parent
        # イベント管理クラスのインスタンスを取得
        self.ifi = IFEvtProp(order)
        #先にスーパークラスのコンストラクタを実行させる
        NavigationToolbar2Wx.__init__(self, parent.canvas)
        # フラグ類の初期化
        self._idle = True
        self.statbar = None
        self.downEvt = None
        self.printingFlag = False
        # イベント格納用リストを準備
        self.evtlst = [None]
 
    ##################################    
    def _init_toolbar(self):
        """
        ツールバーを作成
        @param 無し
        @retval 無し
        """
        #先にスーパークラスのツールバーを作る
        NavigationToolbar2Wx._init_toolbar(self)

        self._parent = self.parent.canvas.GetParent()
        #プリンタのアイコンをツールバーに追加
        _NTB3_PRINT    =wx.NewId()
        self.SetToolBitmapSize(wx.Size(24,24))
        self.AddSeparator()
        self.AddSimpleTool(_NTB3_PRINT, Images().GetBmp("Printer"),
                           'Print', 'Print graph image')

        #プリンタアイコン押下時のイベントハンドラ作成 
        if wx.VERSION_STRING >= '2.5':
            self.Bind(wx.EVT_TOOL, self.OnPrint, id=_NTB3_PRINT)
        else:
            wx.EVT_TOOL(self, _NTB3_PRINT, self.OnPrint)

        self.Realize()
        
    ##################################    
    def OnPrint(self, evt):
        """
        印刷要求を通知
        @param  evt    イベント情報
        @retval 無し
        """ 
        # 印刷イベント通知
        self.ifi.NotifyEvent(self,"print")
        
    ##################################    
    def back(self, evt):
        """
        バックワード処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #先にスーパークラスのバックワード処理処理を実行
        NavigationToolbar2Wx.back(self, evt)
        self.evtPoint = self.evtPoint - 1 
        # ヒストリ処理
        self._GetHistory()
                
    ##################################    
    def forward(self, evt):
        """
        フォワード処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #先にスーパークラスのフォワード処理処理を実行
        NavigationToolbar2Wx.forward(self, evt)
        self.evtPoint += 1
        # ヒストリ処理
        self._GetHistory()
        
    ##################################    
    def _GetHistory(self):
        """
        ヒストリ処理
        @param  無し
        @retval 無し
        """ 
        # イベント取得 
        evt = self.evtlst[self.evtPoint]
        # イベントがNon だったら、Home ボタン押下イベント
        if evt == None:
            # ホームポジションイベントを通知
            self.ifi.NotifyEvent(self,"home")
        else:
            # 表示範囲変更イベントを通知
            self.ifi.NotifyEvent(self,"changexy", self.evtlst[self.evtPoint])                                               
        
    ##################################    
    def home(self, evt):
        """
        ホームポジション処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #先にスーパークラスのホームポジション処理を実行
        try:
            NavigationToolbar2Wx.home(self, evt)
        except:
            # ズーム後にプロットを被せたときに発生する例外の抑制
            pass
        # イベントを格納
        self.evtlst.append(None)
        self.evtPoint = len(self.evtlst)-1
        # ホームポジションイベントを通知
        self.ifi.NotifyEvent(self,"home")   

    ##################################    
    def back(self, evt):
        """
        バックワード処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #スーパークラスのバックワード処理を実行
        try:
            NavigationToolbar2Wx.back(self, evt)
        except:
            # ズーム後にプロットを被せたときに発生する例外の抑制
            pass
        # 表示範囲変更イベントを通知
        self.ifi.NotifyEvent(self,"changexy", (self.downEvt, evt))

    ##################################    
    def forward(self, evt):
        """
        フォワード処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #スーパークラスのフォワード処理を実行
        try:
            NavigationToolbar2Wx.forward(self, evt)
        except:
            # ズーム後にプロットを被せたときに発生する例外の抑制
            pass
        # 表示範囲変更イベントを通知
        self.ifi.NotifyEvent(self,"changexy", (self.downEvt, evt))

    ##################################    
    def release_zoom(self, evt):
        """
        拡大イベント処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #先にスーパークラスのズーム処理を実行
        NavigationToolbar2Wx.release_zoom(self, evt)
        # マウスクリック点がグラフ外であれば
        if self.downEvt == None:
            # 何もしない
            return
        # イベントを格納
        self.evtlst.append((self.downEvt, evt))
        self.evtPoint = len(self.evtlst)-1
        # 表示範囲変更イベントを通知
        self.ifi.NotifyEvent(self,"changexy", (self.downEvt, evt))

    ##################################    
    def release_pan(self, evt):
        """
        パンイベント処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #先にスーパークラスのパン処理を実行
        NavigationToolbar2Wx.release_pan(self, evt)
        # マウスクリック点がグラフ外であれば
        if self.downEvt == None:
            # 何もしない
            return
        # イベントを格納
        self.evtlst.append((self.downEvt, evt))
        self.evtPoint = len(self.evtlst)-1
        # 表示範囲変更イベントを通知
        self.ifi.NotifyEvent(self,"changexy", (self.downEvt, evt))        
        
    ##################################    
    def press_zoom(self, evt):
        """
        拡大イベント処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #先にスーパークラスのズーム処理を実行
        NavigationToolbar2Wx.press_zoom(self, evt)
        # グラフ内であれば
        if evt.inaxes:
            # ドラッグ開始点のイベントを保存
            self.downEvt = evt
        else:
            self.downEvt = None

    ##################################    
    def press_pan(self, evt):
        """
        パンイベント処理 (オーバーライド関数)
        @param  evt    イベント情報
        @retval 無し
        """                  
        #先にスーパークラスのパン処理を実行
        NavigationToolbar2Wx.press_pan(self, evt)
        # グラフ内であれば
        if evt.inaxes:
            # パン開始点のY位置を保存
            self.downEvt = evt
        else:
            self.downEvt = None
        
    ##################################    
    def save(self, evt):
        """
        キャンバスに描画されている画像を保存(オーバライド関数)
        @param evt イベント
        @retval 無
        """ 
        # 画像保存用ファイルの絶対パスを取得

        # 保存ファイルタイプの拡張子を取得

        filetypes = "PNG (*.png)|*.png|PS (*.ps)|*.ps|EPS (*.eps)|*.eps"
        # ファイル保存ダイアログを表示
        dlg =wx.FileDialog(self.parent.frame, "Save the image", "", "", filetypes,
                           wx.SAVE|wx.OVERWRITE_PROMPT|wx.CHANGE_DIR)
        # OK であればファイルを保存

        if dlg.ShowModal() == wx.ID_OK:
           
            # 指定されたパスに日本語が含まれていないかどうかをチェック
            try:
                # wxPython 2.8 on Linux では拡張子を自動付加しない(バグ?)ため
                # 拡張子のチェックを行う。
                path, ext = os.path.splitext(dlg.GetPath())
                # 拡張子が正しく入力されていたらパスを返す 
                if ext == ".png"  or ext == ".ps" or ext ==".eps":
                    # パスに日本語が含まれている場合例外が発生
                    try:
                        fname = str(dlg.GetPath())
                    except:
                        raise PlotException('Common','C021',())
                    else:
                        # パスを指定してファイル保存イベントを通知
                        self.ifi.NotifyEvent(self,"save", fname) 
                else:    
                    # エラーメッセージを表示して保存を行わない
                    raise PlotException('Common','C024',())
            except PlotException, ex:
                PlotMessage(self.parent.frame,ex)
